Class: Aws::PaymentCryptography::Types::CreateAliasInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::CreateAliasInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias_name ⇒ String
A friendly name that you can use to refer to a key.
-
#key_arn ⇒ String
The
KeyARNof the key to associate with the alias.
Instance Attribute Details
#alias_name ⇒ String
A friendly name that you can use to refer to a key. An alias must begin with alias/ followed by a name, for example alias/ExampleAlias. It can contain only alphanumeric characters, forward slashes (/), underscores (_), and dashes (-).
Don’t include personal, confidential or sensitive information in this field. This field may be displayed in plaintext in CloudTrail logs and other output.
80 81 82 83 84 85 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 80 class CreateAliasInput < Struct.new( :alias_name, :key_arn) SENSITIVE = [] include Aws::Structure end |
#key_arn ⇒ String
The KeyARN of the key to associate with the alias.
80 81 82 83 84 85 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 80 class CreateAliasInput < Struct.new( :alias_name, :key_arn) SENSITIVE = [] include Aws::Structure end |