Class: Aws::PaymentCryptography::Types::CreateKeyOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::CreateKeyOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key ⇒ Types::Key
The key material that contains all the key attributes.
Instance Attribute Details
#key ⇒ Types::Key
The key material that contains all the key attributes.
336 337 338 339 340 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 336 class CreateKeyOutput < Struct.new( :key) SENSITIVE = [] include Aws::Structure end |