Class: Aws::PaymentCryptography::Types::DeleteAliasInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::DeleteAliasInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias_name ⇒ String
A friendly name that you can use to refer Amazon Web Services Payment Cryptography key.
Instance Attribute Details
#alias_name ⇒ String
A friendly name that you can use to refer Amazon Web Services Payment Cryptography key. This value must begin with alias/ followed by a name, such as alias/ExampleAlias.
308 309 310 311 312 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 308 class DeleteAliasInput < Struct.new( :alias_name) SENSITIVE = [] include Aws::Structure end |