Class: Aws::PaymentCryptography::Types::DisableDefaultKeyReplicationRegionsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-paymentcryptography/types.rb

Overview

Input parameters for disabling default key replication regions for the account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#replication_regionsArray<String>

The list of Amazon Web Services Regions to remove from the account’s default replication regions.

New keys created after this operation will not automatically be replicated to these regions, though existing keys with replication to these regions will be unaffected.

Returns:

  • (Array<String>)


448
449
450
451
452
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 448

class DisableDefaultKeyReplicationRegionsInput < Struct.new(
  :replication_regions)
  SENSITIVE = []
  include Aws::Structure
end