Class: Aws::PaymentCryptography::Types::DisableDefaultKeyReplicationRegionsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::DisableDefaultKeyReplicationRegionsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Output from disabling default key replication regions for the account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled_replication_regions ⇒ Array<String>
The remaining list of regions where default key replication is still enabled for the account.
Instance Attribute Details
#enabled_replication_regions ⇒ Array<String>
The remaining list of regions where default key replication is still enabled for the account.
This reflects the account’s default replication configuration after removing the specified regions.
466 467 468 469 470 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 466 class DisableDefaultKeyReplicationRegionsOutput < Struct.new( :enabled_replication_regions) SENSITIVE = [] include Aws::Structure end |