Class: Aws::PaymentCryptography::Types::ExportKeyInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::ExportKeyInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#export_attributes ⇒ Types::ExportAttributes
The attributes for IPEK generation during export.
-
#export_key_identifier ⇒ String
The
KeyARNof the key under export from Amazon Web Services Payment Cryptography. -
#key_material ⇒ Types::ExportKeyMaterial
The key block format type, for example, TR-34 or TR-31, to use during key material export.
Instance Attribute Details
#export_attributes ⇒ Types::ExportAttributes
The attributes for IPEK generation during export.
632 633 634 635 636 637 638 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 632 class ExportKeyInput < Struct.new( :key_material, :export_key_identifier, :export_attributes) SENSITIVE = [] include Aws::Structure end |
#export_key_identifier ⇒ String
The KeyARN of the key under export from Amazon Web Services Payment Cryptography.
632 633 634 635 636 637 638 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 632 class ExportKeyInput < Struct.new( :key_material, :export_key_identifier, :export_attributes) SENSITIVE = [] include Aws::Structure end |
#key_material ⇒ Types::ExportKeyMaterial
The key block format type, for example, TR-34 or TR-31, to use during key material export.
632 633 634 635 636 637 638 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 632 class ExportKeyInput < Struct.new( :key_material, :export_key_identifier, :export_attributes) SENSITIVE = [] include Aws::Structure end |