Class: Aws::PaymentCryptography::Types::ExportTr34KeyBlock

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-paymentcryptography/types.rb

Overview

Parameter information for key material export using the asymmetric TR-34 key exchange method.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_authority_public_key_identifierString

The KeyARN of the certificate chain that signs the wrapping key certificate during TR-34 key export.

Returns:

  • (String)


780
781
782
783
784
785
786
787
788
789
790
791
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 780

class ExportTr34KeyBlock < Struct.new(
  :certificate_authority_public_key_identifier,
  :wrapping_key_certificate,
  :export_token,
  :signing_key_identifier,
  :signing_key_certificate,
  :key_block_format,
  :random_nonce,
  :key_block_headers)
  SENSITIVE = []
  include Aws::Structure
end

#export_tokenString

The export token to initiate key export from Amazon Web Services Payment Cryptography. It also contains the signing key certificate that will sign the wrapped key during TR-34 key block generation. Call [GetParametersForExport] to receive an export token. It expires after 30 days. You can use the same export token to export multiple keys from the same service account.

[1]: docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_GetParametersForExport.html

Returns:

  • (String)


780
781
782
783
784
785
786
787
788
789
790
791
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 780

class ExportTr34KeyBlock < Struct.new(
  :certificate_authority_public_key_identifier,
  :wrapping_key_certificate,
  :export_token,
  :signing_key_identifier,
  :signing_key_certificate,
  :key_block_format,
  :random_nonce,
  :key_block_headers)
  SENSITIVE = []
  include Aws::Structure
end

#key_block_formatString

The format of key block that Amazon Web Services Payment Cryptography will use during key export.

Returns:

  • (String)


780
781
782
783
784
785
786
787
788
789
790
791
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 780

class ExportTr34KeyBlock < Struct.new(
  :certificate_authority_public_key_identifier,
  :wrapping_key_certificate,
  :export_token,
  :signing_key_identifier,
  :signing_key_certificate,
  :key_block_format,
  :random_nonce,
  :key_block_headers)
  SENSITIVE = []
  include Aws::Structure
end

#key_block_headersTypes::KeyBlockHeaders

Optional metadata for export associated with the key material. This data is signed but transmitted in clear text.



780
781
782
783
784
785
786
787
788
789
790
791
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 780

class ExportTr34KeyBlock < Struct.new(
  :certificate_authority_public_key_identifier,
  :wrapping_key_certificate,
  :export_token,
  :signing_key_identifier,
  :signing_key_certificate,
  :key_block_format,
  :random_nonce,
  :key_block_headers)
  SENSITIVE = []
  include Aws::Structure
end

#random_nonceString

A random number value that is unique to the TR-34 key block generated using 2 pass. The operation will fail, if a random nonce value is not provided for a TR-34 key block generated using 2 pass.

Returns:

  • (String)


780
781
782
783
784
785
786
787
788
789
790
791
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 780

class ExportTr34KeyBlock < Struct.new(
  :certificate_authority_public_key_identifier,
  :wrapping_key_certificate,
  :export_token,
  :signing_key_identifier,
  :signing_key_certificate,
  :key_block_format,
  :random_nonce,
  :key_block_headers)
  SENSITIVE = []
  include Aws::Structure
end

#signing_key_certificateString

The certificate used to sign the TR-34 key block.

Returns:

  • (String)


780
781
782
783
784
785
786
787
788
789
790
791
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 780

class ExportTr34KeyBlock < Struct.new(
  :certificate_authority_public_key_identifier,
  :wrapping_key_certificate,
  :export_token,
  :signing_key_identifier,
  :signing_key_certificate,
  :key_block_format,
  :random_nonce,
  :key_block_headers)
  SENSITIVE = []
  include Aws::Structure
end

#signing_key_identifierString

Key Identifier used for signing the export key

Returns:

  • (String)


780
781
782
783
784
785
786
787
788
789
790
791
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 780

class ExportTr34KeyBlock < Struct.new(
  :certificate_authority_public_key_identifier,
  :wrapping_key_certificate,
  :export_token,
  :signing_key_identifier,
  :signing_key_certificate,
  :key_block_format,
  :random_nonce,
  :key_block_headers)
  SENSITIVE = []
  include Aws::Structure
end

#wrapping_key_certificateString

The KeyARN of the wrapping key certificate. Amazon Web Services Payment Cryptography uses this certificate to wrap the key under export.

Returns:

  • (String)


780
781
782
783
784
785
786
787
788
789
790
791
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 780

class ExportTr34KeyBlock < Struct.new(
  :certificate_authority_public_key_identifier,
  :wrapping_key_certificate,
  :export_token,
  :signing_key_identifier,
  :signing_key_certificate,
  :key_block_format,
  :random_nonce,
  :key_block_headers)
  SENSITIVE = []
  include Aws::Structure
end