Class: Aws::PaymentCryptography::Types::GetAliasInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::GetAliasInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias_name ⇒ String
The alias of the Amazon Web Services Payment Cryptography key.
Instance Attribute Details
#alias_name ⇒ String
The alias of the Amazon Web Services Payment Cryptography key.
799 800 801 802 803 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 799 class GetAliasInput < Struct.new( :alias_name) SENSITIVE = [] include Aws::Structure end |