Class: Aws::PaymentCryptography::Types::GetAliasOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::GetAliasOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ Types::Alias
The alias of the Amazon Web Services Payment Cryptography key.
Instance Attribute Details
#alias ⇒ Types::Alias
The alias of the Amazon Web Services Payment Cryptography key.
908 909 910 911 912 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 908 class GetAliasOutput < Struct.new( :alias) SENSITIVE = [] include Aws::Structure end |