Class: Aws::PaymentCryptography::Types::GetDefaultKeyReplicationRegionsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-paymentcryptography/types.rb

Overview

Output containing the account’s current default key replication configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabled_replication_regionsArray<String>

The list of regions where default key replication is currently enabled for the account.

New keys created in this account will automatically be replicated to these regions unless explicitly configured otherwise during key creation.

Returns:

  • (Array<String>)


972
973
974
975
976
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 972

class GetDefaultKeyReplicationRegionsOutput < Struct.new(
  :enabled_replication_regions)
  SENSITIVE = []
  include Aws::Structure
end