Class: Aws::PaymentCryptography::Types::GetKeyOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::GetKeyOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key ⇒ Types::Key
Contains the key metadata, including both immutable and mutable attributes for the key, but does not include actual cryptographic key material.
Instance Attribute Details
#key ⇒ Types::Key
Contains the key metadata, including both immutable and mutable attributes for the key, but does not include actual cryptographic key material.
901 902 903 904 905 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 901 class GetKeyOutput < Struct.new( :key) SENSITIVE = [] include Aws::Structure end |