Class: Aws::PaymentCryptography::Types::ImportAs2805KeyCryptogram
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::ImportAs2805KeyCryptogram
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Parameter information for key material import using AS2805 key cryptogram format.
Constant Summary collapse
- SENSITIVE =
[:wrapped_key_cryptogram]
Instance Attribute Summary collapse
-
#as_2805_key_variant ⇒ String
The cryptographic usage of the key under import.
-
#exportable ⇒ Boolean
Specified whether the key is exportable.
-
#key_algorithm ⇒ String
The key algorithm of the key under import.
-
#key_modes_of_use ⇒ Types::KeyModesOfUse
The list of cryptographic operations that you can perform using the key.
-
#wrapped_key_cryptogram ⇒ String
The wrapped key cryptogram under import.
-
#wrapping_key_identifier ⇒ String
A key identifier that can be either a key ARN or an alias name.
Instance Attribute Details
#as_2805_key_variant ⇒ String
The cryptographic usage of the key under import.
1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1288 class ImportAs2805KeyCryptogram < Struct.new( :as_2805_key_variant, :key_modes_of_use, :key_algorithm, :exportable, :wrapping_key_identifier, :wrapped_key_cryptogram) SENSITIVE = [:wrapped_key_cryptogram] include Aws::Structure end |
#exportable ⇒ Boolean
Specified whether the key is exportable. This data is immutable after the key is imported.
1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1288 class ImportAs2805KeyCryptogram < Struct.new( :as_2805_key_variant, :key_modes_of_use, :key_algorithm, :exportable, :wrapping_key_identifier, :wrapped_key_cryptogram) SENSITIVE = [:wrapped_key_cryptogram] include Aws::Structure end |
#key_algorithm ⇒ String
The key algorithm of the key under import.
1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1288 class ImportAs2805KeyCryptogram < Struct.new( :as_2805_key_variant, :key_modes_of_use, :key_algorithm, :exportable, :wrapping_key_identifier, :wrapped_key_cryptogram) SENSITIVE = [:wrapped_key_cryptogram] include Aws::Structure end |
#key_modes_of_use ⇒ Types::KeyModesOfUse
The list of cryptographic operations that you can perform using the key. The modes of use are defined in section A.5.3 of the TR-31 spec.
1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1288 class ImportAs2805KeyCryptogram < Struct.new( :as_2805_key_variant, :key_modes_of_use, :key_algorithm, :exportable, :wrapping_key_identifier, :wrapped_key_cryptogram) SENSITIVE = [:wrapped_key_cryptogram] include Aws::Structure end |
#wrapped_key_cryptogram ⇒ String
The wrapped key cryptogram under import.
1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1288 class ImportAs2805KeyCryptogram < Struct.new( :as_2805_key_variant, :key_modes_of_use, :key_algorithm, :exportable, :wrapping_key_identifier, :wrapped_key_cryptogram) SENSITIVE = [:wrapped_key_cryptogram] include Aws::Structure end |
#wrapping_key_identifier ⇒ String
A key identifier that can be either a key ARN or an alias name. This allows flexible key identification in operations.
When using a key ARN, it must be a fully qualified ARN in the format: ‘arn:aws:payment-cryptography:region:account:key/key-id`.
When using an alias, it must begin with ‘alias/` followed by the alias name.
Do not include confidential or sensitive information in this field. This field may be displayed in plaintext in CloudTrail logs and other output.
1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1288 class ImportAs2805KeyCryptogram < Struct.new( :as_2805_key_variant, :key_modes_of_use, :key_algorithm, :exportable, :wrapping_key_identifier, :wrapped_key_cryptogram) SENSITIVE = [:wrapped_key_cryptogram] include Aws::Structure end |