Class: Aws::PaymentCryptography::Types::ImportKeyCryptogram

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-paymentcryptography/types.rb

Overview

Parameter information for key material import using asymmetric RSA wrap and unwrap key exchange method.

Constant Summary collapse

SENSITIVE =
[:wrapped_key_cryptogram]

Instance Attribute Summary collapse

Instance Attribute Details

#exportableBoolean

Specifies whether the key is exportable from the service.

Returns:

  • (Boolean)


1386
1387
1388
1389
1390
1391
1392
1393
1394
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1386

class ImportKeyCryptogram < Struct.new(
  :key_attributes,
  :exportable,
  :wrapped_key_cryptogram,
  :import_token,
  :wrapping_spec)
  SENSITIVE = [:wrapped_key_cryptogram]
  include Aws::Structure
end

#import_tokenString

The import token that initiates key import using the asymmetric RSA wrap and unwrap key exchange method into AWS Payment Cryptography. It expires after 30 days. You can use the same import token to import multiple keys to the same service account.

Returns:

  • (String)


1386
1387
1388
1389
1390
1391
1392
1393
1394
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1386

class ImportKeyCryptogram < Struct.new(
  :key_attributes,
  :exportable,
  :wrapped_key_cryptogram,
  :import_token,
  :wrapping_spec)
  SENSITIVE = [:wrapped_key_cryptogram]
  include Aws::Structure
end

#key_attributesTypes::KeyAttributes

The role of the key, the algorithm it supports, and the cryptographic operations allowed with the key. This data is immutable after the key is created.



1386
1387
1388
1389
1390
1391
1392
1393
1394
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1386

class ImportKeyCryptogram < Struct.new(
  :key_attributes,
  :exportable,
  :wrapped_key_cryptogram,
  :import_token,
  :wrapping_spec)
  SENSITIVE = [:wrapped_key_cryptogram]
  include Aws::Structure
end

#wrapped_key_cryptogramString

The RSA wrapped key cryptogram under import.

Returns:

  • (String)


1386
1387
1388
1389
1390
1391
1392
1393
1394
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1386

class ImportKeyCryptogram < Struct.new(
  :key_attributes,
  :exportable,
  :wrapped_key_cryptogram,
  :import_token,
  :wrapping_spec)
  SENSITIVE = [:wrapped_key_cryptogram]
  include Aws::Structure
end

#wrapping_specString

The wrapping spec for the wrapped key cryptogram.

Returns:

  • (String)


1386
1387
1388
1389
1390
1391
1392
1393
1394
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1386

class ImportKeyCryptogram < Struct.new(
  :key_attributes,
  :exportable,
  :wrapped_key_cryptogram,
  :import_token,
  :wrapping_spec)
  SENSITIVE = [:wrapped_key_cryptogram]
  include Aws::Structure
end