Class: Aws::PaymentCryptography::Types::ImportKeyInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-paymentcryptography/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

Specifies whether import key is enabled.

Returns:

  • (Boolean)


1278
1279
1280
1281
1282
1283
1284
1285
1286
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1278

class ImportKeyInput < Struct.new(
  :key_material,
  :key_check_value_algorithm,
  :enabled,
  :tags,
  :replication_regions)
  SENSITIVE = []
  include Aws::Structure
end

#key_check_value_algorithmString

The algorithm that Amazon Web Services Payment Cryptography uses to calculate the key check value (KCV). It is used to validate the key integrity.

For TDES keys, the KCV is computed by encrypting 8 bytes, each with value of zero, with the key to be checked and retaining the 3 highest order bytes of the encrypted result. For AES keys, the KCV is computed using a CMAC algorithm where the input data is 16 bytes of zero and retaining the 3 highest order bytes of the encrypted result.

Returns:

  • (String)


1278
1279
1280
1281
1282
1283
1284
1285
1286
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1278

class ImportKeyInput < Struct.new(
  :key_material,
  :key_check_value_algorithm,
  :enabled,
  :tags,
  :replication_regions)
  SENSITIVE = []
  include Aws::Structure
end

#key_materialTypes::ImportKeyMaterial

The key or public key certificate type to use during key material import, for example TR-34 or RootCertificatePublicKey.



1278
1279
1280
1281
1282
1283
1284
1285
1286
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1278

class ImportKeyInput < Struct.new(
  :key_material,
  :key_check_value_algorithm,
  :enabled,
  :tags,
  :replication_regions)
  SENSITIVE = []
  include Aws::Structure
end

#replication_regionsArray<String>

A list of Amazon Web Services Regions for key replication operations.

Each region in the list must be a valid Amazon Web Services Region identifier where Amazon Web Services Payment Cryptography is available. This list is used to specify which regions should be added to or removed from a key’s replication configuration.

Returns:

  • (Array<String>)


1278
1279
1280
1281
1282
1283
1284
1285
1286
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1278

class ImportKeyInput < Struct.new(
  :key_material,
  :key_check_value_algorithm,
  :enabled,
  :tags,
  :replication_regions)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Assigns one or more tags to the Amazon Web Services Payment Cryptography key. Use this parameter to tag a key when it is imported. To tag an existing Amazon Web Services Payment Cryptography key, use the [TagResource] operation.

Each tag consists of a tag key and a tag value. Both the tag key and the tag value are required, but the tag value can be an empty (null) string. You can’t have more than one tag on an Amazon Web Services Payment Cryptography key with the same tag key. If you specify an existing tag key with a different tag value, Amazon Web Services Payment Cryptography replaces the current tag value with the specified one.

Don’t include personal, confidential or sensitive information in this field. This field may be displayed in plaintext in CloudTrail logs and other output.

<note markdown=“1”> Tagging or untagging an Amazon Web Services Payment Cryptography key can allow or deny permission to the key.

</note>

[1]: docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_TagResource.html

Returns:



1278
1279
1280
1281
1282
1283
1284
1285
1286
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1278

class ImportKeyInput < Struct.new(
  :key_material,
  :key_check_value_algorithm,
  :enabled,
  :tags,
  :replication_regions)
  SENSITIVE = []
  include Aws::Structure
end