Class: Aws::PaymentCryptography::Types::ImportTr31KeyBlock

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-paymentcryptography/types.rb

Overview

Parameter information for key material import using symmetric TR-31 key exchange method.

Constant Summary collapse

SENSITIVE =
[:wrapped_key_block]

Instance Attribute Summary collapse

Instance Attribute Details

#wrapped_key_blockString

The TR-31 wrapped key block to import.

Returns:

  • (String)


1564
1565
1566
1567
1568
1569
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1564

class ImportTr31KeyBlock < Struct.new(
  :wrapping_key_identifier,
  :wrapped_key_block)
  SENSITIVE = [:wrapped_key_block]
  include Aws::Structure
end

#wrapping_key_identifierString

The ‘KeyARN` of the key that will decrypt or unwrap a TR-31 key block during import.

Returns:

  • (String)


1564
1565
1566
1567
1568
1569
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1564

class ImportTr31KeyBlock < Struct.new(
  :wrapping_key_identifier,
  :wrapped_key_block)
  SENSITIVE = [:wrapped_key_block]
  include Aws::Structure
end