Class: Aws::PaymentCryptography::Types::Key

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-paymentcryptography/types.rb

Overview

Metadata about an Amazon Web Services Payment Cryptography key.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#create_timestampTime

The date and time when the key was created.

Returns:

  • (Time)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1788

class Key < Struct.new(
  :key_arn,
  :key_attributes,
  :key_check_value,
  :key_check_value_algorithm,
  :enabled,
  :exportable,
  :key_state,
  :key_origin,
  :create_timestamp,
  :usage_start_timestamp,
  :usage_stop_timestamp,
  :delete_pending_timestamp,
  :delete_timestamp,
  :derive_key_usage,
  :multi_region_key_type,
  :primary_region,
  :replication_status,
  :using_default_replication_regions,
  :mpa_status)
  SENSITIVE = []
  include Aws::Structure
end

#delete_pending_timestampTime

The date and time after which Amazon Web Services Payment Cryptography will delete the key. This value is present only when ‘KeyState` is `DELETE_PENDING` and the key is scheduled for deletion.

Returns:

  • (Time)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1788

class Key < Struct.new(
  :key_arn,
  :key_attributes,
  :key_check_value,
  :key_check_value_algorithm,
  :enabled,
  :exportable,
  :key_state,
  :key_origin,
  :create_timestamp,
  :usage_start_timestamp,
  :usage_stop_timestamp,
  :delete_pending_timestamp,
  :delete_timestamp,
  :derive_key_usage,
  :multi_region_key_type,
  :primary_region,
  :replication_status,
  :using_default_replication_regions,
  :mpa_status)
  SENSITIVE = []
  include Aws::Structure
end

#delete_timestampTime

The date and time after which Amazon Web Services Payment Cryptography will delete the key. This value is present only when when the ‘KeyState` is `DELETE_COMPLETE` and the Amazon Web Services Payment Cryptography key is deleted.

Returns:

  • (Time)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1788

class Key < Struct.new(
  :key_arn,
  :key_attributes,
  :key_check_value,
  :key_check_value_algorithm,
  :enabled,
  :exportable,
  :key_state,
  :key_origin,
  :create_timestamp,
  :usage_start_timestamp,
  :usage_stop_timestamp,
  :delete_pending_timestamp,
  :delete_timestamp,
  :derive_key_usage,
  :multi_region_key_type,
  :primary_region,
  :replication_status,
  :using_default_replication_regions,
  :mpa_status)
  SENSITIVE = []
  include Aws::Structure
end

#derive_key_usageString

The cryptographic usage of an ECDH derived key as defined in section A.5.2 of the TR-31 spec.

Returns:

  • (String)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1788

class Key < Struct.new(
  :key_arn,
  :key_attributes,
  :key_check_value,
  :key_check_value_algorithm,
  :enabled,
  :exportable,
  :key_state,
  :key_origin,
  :create_timestamp,
  :usage_start_timestamp,
  :usage_stop_timestamp,
  :delete_pending_timestamp,
  :delete_timestamp,
  :derive_key_usage,
  :multi_region_key_type,
  :primary_region,
  :replication_status,
  :using_default_replication_regions,
  :mpa_status)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

Specifies whether the key is enabled.

Returns:

  • (Boolean)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1788

class Key < Struct.new(
  :key_arn,
  :key_attributes,
  :key_check_value,
  :key_check_value_algorithm,
  :enabled,
  :exportable,
  :key_state,
  :key_origin,
  :create_timestamp,
  :usage_start_timestamp,
  :usage_stop_timestamp,
  :delete_pending_timestamp,
  :delete_timestamp,
  :derive_key_usage,
  :multi_region_key_type,
  :primary_region,
  :replication_status,
  :using_default_replication_regions,
  :mpa_status)
  SENSITIVE = []
  include Aws::Structure
end

#exportableBoolean

Specifies whether the key is exportable. This data is immutable after the key is created.

Returns:

  • (Boolean)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1788

class Key < Struct.new(
  :key_arn,
  :key_attributes,
  :key_check_value,
  :key_check_value_algorithm,
  :enabled,
  :exportable,
  :key_state,
  :key_origin,
  :create_timestamp,
  :usage_start_timestamp,
  :usage_stop_timestamp,
  :delete_pending_timestamp,
  :delete_timestamp,
  :derive_key_usage,
  :multi_region_key_type,
  :primary_region,
  :replication_status,
  :using_default_replication_regions,
  :mpa_status)
  SENSITIVE = []
  include Aws::Structure
end

#key_arnString

The Amazon Resource Name (ARN) of the key.

Returns:

  • (String)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1788

class Key < Struct.new(
  :key_arn,
  :key_attributes,
  :key_check_value,
  :key_check_value_algorithm,
  :enabled,
  :exportable,
  :key_state,
  :key_origin,
  :create_timestamp,
  :usage_start_timestamp,
  :usage_stop_timestamp,
  :delete_pending_timestamp,
  :delete_timestamp,
  :derive_key_usage,
  :multi_region_key_type,
  :primary_region,
  :replication_status,
  :using_default_replication_regions,
  :mpa_status)
  SENSITIVE = []
  include Aws::Structure
end

#key_attributesTypes::KeyAttributes

The role of the key, the algorithm it supports, and the cryptographic operations allowed with the key. This data is immutable after the key is created.



1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1788

class Key < Struct.new(
  :key_arn,
  :key_attributes,
  :key_check_value,
  :key_check_value_algorithm,
  :enabled,
  :exportable,
  :key_state,
  :key_origin,
  :create_timestamp,
  :usage_start_timestamp,
  :usage_stop_timestamp,
  :delete_pending_timestamp,
  :delete_timestamp,
  :derive_key_usage,
  :multi_region_key_type,
  :primary_region,
  :replication_status,
  :using_default_replication_regions,
  :mpa_status)
  SENSITIVE = []
  include Aws::Structure
end

#key_check_valueString

The key check value (KCV) is used to check if all parties holding a given key have the same key or to detect that a key has changed.

Returns:

  • (String)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1788

class Key < Struct.new(
  :key_arn,
  :key_attributes,
  :key_check_value,
  :key_check_value_algorithm,
  :enabled,
  :exportable,
  :key_state,
  :key_origin,
  :create_timestamp,
  :usage_start_timestamp,
  :usage_stop_timestamp,
  :delete_pending_timestamp,
  :delete_timestamp,
  :derive_key_usage,
  :multi_region_key_type,
  :primary_region,
  :replication_status,
  :using_default_replication_regions,
  :mpa_status)
  SENSITIVE = []
  include Aws::Structure
end

#key_check_value_algorithmString

The algorithm that Amazon Web Services Payment Cryptography uses to calculate the key check value (KCV). It is used to validate the key integrity.

For TDES keys, the KCV is computed by encrypting 8 bytes, each with value of zero, with the key to be checked and retaining the 3 highest order bytes of the encrypted result. For AES keys, the KCV is computed using a CMAC algorithm where the input data is 16 bytes of zero and retaining the 3 highest order bytes of the encrypted result.

Returns:

  • (String)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1788

class Key < Struct.new(
  :key_arn,
  :key_attributes,
  :key_check_value,
  :key_check_value_algorithm,
  :enabled,
  :exportable,
  :key_state,
  :key_origin,
  :create_timestamp,
  :usage_start_timestamp,
  :usage_stop_timestamp,
  :delete_pending_timestamp,
  :delete_timestamp,
  :derive_key_usage,
  :multi_region_key_type,
  :primary_region,
  :replication_status,
  :using_default_replication_regions,
  :mpa_status)
  SENSITIVE = []
  include Aws::Structure
end

#key_originString

The source of the key material. For keys created within Amazon Web Services Payment Cryptography, the value is ‘AWS_PAYMENT_CRYPTOGRAPHY`. For keys imported into Amazon Web Services Payment Cryptography, the value is `EXTERNAL`.

Returns:

  • (String)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1788

class Key < Struct.new(
  :key_arn,
  :key_attributes,
  :key_check_value,
  :key_check_value_algorithm,
  :enabled,
  :exportable,
  :key_state,
  :key_origin,
  :create_timestamp,
  :usage_start_timestamp,
  :usage_stop_timestamp,
  :delete_pending_timestamp,
  :delete_timestamp,
  :derive_key_usage,
  :multi_region_key_type,
  :primary_region,
  :replication_status,
  :using_default_replication_regions,
  :mpa_status)
  SENSITIVE = []
  include Aws::Structure
end

#key_stateString

The state of key that is being created or deleted.

Returns:

  • (String)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1788

class Key < Struct.new(
  :key_arn,
  :key_attributes,
  :key_check_value,
  :key_check_value_algorithm,
  :enabled,
  :exportable,
  :key_state,
  :key_origin,
  :create_timestamp,
  :usage_start_timestamp,
  :usage_stop_timestamp,
  :delete_pending_timestamp,
  :delete_timestamp,
  :derive_key_usage,
  :multi_region_key_type,
  :primary_region,
  :replication_status,
  :using_default_replication_regions,
  :mpa_status)
  SENSITIVE = []
  include Aws::Structure
end

#mpa_statusTypes::MpaStatus

The Multi-Party Approval (MPA) status for the key, if applicable.

Returns:



1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1788

class Key < Struct.new(
  :key_arn,
  :key_attributes,
  :key_check_value,
  :key_check_value_algorithm,
  :enabled,
  :exportable,
  :key_state,
  :key_origin,
  :create_timestamp,
  :usage_start_timestamp,
  :usage_stop_timestamp,
  :delete_pending_timestamp,
  :delete_timestamp,
  :derive_key_usage,
  :multi_region_key_type,
  :primary_region,
  :replication_status,
  :using_default_replication_regions,
  :mpa_status)
  SENSITIVE = []
  include Aws::Structure
end

#multi_region_key_typeString

Indicates whether this key is a Multi-Region key and its role in the Multi-Region key hierarchy.

Multi-Region replication keys allow the same key material to be used across multiple Amazon Web Services Regions. This field specifies whether the key is a Primary Region key (PRK) (which can be replicated to other Amazon Web Services Regions) or a Replica Region key (RRK) (which is a copy of a PRK in another Region). For more information, see [Multi-Region key replication].

[1]: docs.aws.amazon.com/payment-cryptography/latest/userguide/keys-multi-region-replication.html

Returns:

  • (String)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1788

class Key < Struct.new(
  :key_arn,
  :key_attributes,
  :key_check_value,
  :key_check_value_algorithm,
  :enabled,
  :exportable,
  :key_state,
  :key_origin,
  :create_timestamp,
  :usage_start_timestamp,
  :usage_stop_timestamp,
  :delete_pending_timestamp,
  :delete_timestamp,
  :derive_key_usage,
  :multi_region_key_type,
  :primary_region,
  :replication_status,
  :using_default_replication_regions,
  :mpa_status)
  SENSITIVE = []
  include Aws::Structure
end

#primary_regionString

An Amazon Web Services Region identifier in the standard format (e.g., ‘us-east-1`, `eu-west-1`).

Used to specify regions for key replication operations. The region must be a valid Amazon Web Services Region where Amazon Web Services Payment Cryptography is available.

Returns:

  • (String)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1788

class Key < Struct.new(
  :key_arn,
  :key_attributes,
  :key_check_value,
  :key_check_value_algorithm,
  :enabled,
  :exportable,
  :key_state,
  :key_origin,
  :create_timestamp,
  :usage_start_timestamp,
  :usage_stop_timestamp,
  :delete_pending_timestamp,
  :delete_timestamp,
  :derive_key_usage,
  :multi_region_key_type,
  :primary_region,
  :replication_status,
  :using_default_replication_regions,
  :mpa_status)
  SENSITIVE = []
  include Aws::Structure
end

#replication_statusHash<String,Types::ReplicationStatusType>

Information about the replication status of the key across different Amazon Web Services Regions.

This field provides details about the current state of key replication, including any status messages or operational information. It helps track the progress and health of key replication operations.

Returns:



1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1788

class Key < Struct.new(
  :key_arn,
  :key_attributes,
  :key_check_value,
  :key_check_value_algorithm,
  :enabled,
  :exportable,
  :key_state,
  :key_origin,
  :create_timestamp,
  :usage_start_timestamp,
  :usage_stop_timestamp,
  :delete_pending_timestamp,
  :delete_timestamp,
  :derive_key_usage,
  :multi_region_key_type,
  :primary_region,
  :replication_status,
  :using_default_replication_regions,
  :mpa_status)
  SENSITIVE = []
  include Aws::Structure
end

#usage_start_timestampTime

The date and time after which Amazon Web Services Payment Cryptography will start using the key material for cryptographic operations.

Returns:

  • (Time)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1788

class Key < Struct.new(
  :key_arn,
  :key_attributes,
  :key_check_value,
  :key_check_value_algorithm,
  :enabled,
  :exportable,
  :key_state,
  :key_origin,
  :create_timestamp,
  :usage_start_timestamp,
  :usage_stop_timestamp,
  :delete_pending_timestamp,
  :delete_timestamp,
  :derive_key_usage,
  :multi_region_key_type,
  :primary_region,
  :replication_status,
  :using_default_replication_regions,
  :mpa_status)
  SENSITIVE = []
  include Aws::Structure
end

#usage_stop_timestampTime

The date and time after which Amazon Web Services Payment Cryptography will stop using the key material for cryptographic operations.

Returns:

  • (Time)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1788

class Key < Struct.new(
  :key_arn,
  :key_attributes,
  :key_check_value,
  :key_check_value_algorithm,
  :enabled,
  :exportable,
  :key_state,
  :key_origin,
  :create_timestamp,
  :usage_start_timestamp,
  :usage_stop_timestamp,
  :delete_pending_timestamp,
  :delete_timestamp,
  :derive_key_usage,
  :multi_region_key_type,
  :primary_region,
  :replication_status,
  :using_default_replication_regions,
  :mpa_status)
  SENSITIVE = []
  include Aws::Structure
end

#using_default_replication_regionsBoolean

Indicates whether this key is using the account’s default replication regions configuration for [Multi-Region key replication].

When set to ‘true`, the key automatically replicates to the regions specified in the account’s default replication settings. When set to ‘false`, the key has a custom replication configuration that overrides the account defaults.

[1]: docs.aws.amazon.com/payment-cryptography/latest/userguide/keys-multi-region-replication.html

Returns:

  • (Boolean)


1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1788

class Key < Struct.new(
  :key_arn,
  :key_attributes,
  :key_check_value,
  :key_check_value_algorithm,
  :enabled,
  :exportable,
  :key_state,
  :key_origin,
  :create_timestamp,
  :usage_start_timestamp,
  :usage_stop_timestamp,
  :delete_pending_timestamp,
  :delete_timestamp,
  :derive_key_usage,
  :multi_region_key_type,
  :primary_region,
  :replication_status,
  :using_default_replication_regions,
  :mpa_status)
  SENSITIVE = []
  include Aws::Structure
end