Class: Aws::PaymentCryptography::Types::KeyAttributes

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-paymentcryptography/types.rb

Overview

The role of the key, the algorithm it supports, and the cryptographic operations allowed with the key. This data is immutable after the key is created.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#key_algorithmString

The key algorithm to be use during creation of an Amazon Web Services Payment Cryptography key.

For symmetric keys, Amazon Web Services Payment Cryptography supports ‘AES` and `TDES` algorithms. For asymmetric keys, Amazon Web Services Payment Cryptography supports `RSA` and `ECC_NIST` algorithms.

Returns:

  • (String)


1853
1854
1855
1856
1857
1858
1859
1860
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1853

class KeyAttributes < Struct.new(
  :key_usage,
  :key_class,
  :key_algorithm,
  :key_modes_of_use)
  SENSITIVE = []
  include Aws::Structure
end

#key_classString

The type of Amazon Web Services Payment Cryptography key to create, which determines the classification of the cryptographic method and whether Amazon Web Services Payment Cryptography key contains a symmetric key or an asymmetric key pair.

Returns:

  • (String)


1853
1854
1855
1856
1857
1858
1859
1860
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1853

class KeyAttributes < Struct.new(
  :key_usage,
  :key_class,
  :key_algorithm,
  :key_modes_of_use)
  SENSITIVE = []
  include Aws::Structure
end

#key_modes_of_useTypes::KeyModesOfUse

The list of cryptographic operations that you can perform using the key.



1853
1854
1855
1856
1857
1858
1859
1860
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1853

class KeyAttributes < Struct.new(
  :key_usage,
  :key_class,
  :key_algorithm,
  :key_modes_of_use)
  SENSITIVE = []
  include Aws::Structure
end

#key_usageString

The cryptographic usage of an Amazon Web Services Payment Cryptography key as defined in section A.5.2 of the TR-31 spec.

Returns:

  • (String)


1853
1854
1855
1856
1857
1858
1859
1860
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1853

class KeyAttributes < Struct.new(
  :key_usage,
  :key_class,
  :key_algorithm,
  :key_modes_of_use)
  SENSITIVE = []
  include Aws::Structure
end