Class: Aws::PaymentCryptography::Types::KeySummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-paymentcryptography/types.rb

Overview

Metadata about an Amazon Web Services Payment Cryptography key.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

Specifies whether the key is enabled.

Returns:

  • (Boolean)


2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2045

class KeySummary < Struct.new(
  :key_arn,
  :key_state,
  :key_attributes,
  :key_check_value,
  :exportable,
  :enabled,
  :multi_region_key_type,
  :primary_region)
  SENSITIVE = []
  include Aws::Structure
end

#exportableBoolean

Specifies whether the key is exportable. This data is immutable after the key is created.

Returns:

  • (Boolean)


2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2045

class KeySummary < Struct.new(
  :key_arn,
  :key_state,
  :key_attributes,
  :key_check_value,
  :exportable,
  :enabled,
  :multi_region_key_type,
  :primary_region)
  SENSITIVE = []
  include Aws::Structure
end

#key_arnString

The Amazon Resource Name (ARN) of the key.

Returns:

  • (String)


2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2045

class KeySummary < Struct.new(
  :key_arn,
  :key_state,
  :key_attributes,
  :key_check_value,
  :exportable,
  :enabled,
  :multi_region_key_type,
  :primary_region)
  SENSITIVE = []
  include Aws::Structure
end

#key_attributesTypes::KeyAttributes

The role of the key, the algorithm it supports, and the cryptographic operations allowed with the key. This data is immutable after the key is created.



2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2045

class KeySummary < Struct.new(
  :key_arn,
  :key_state,
  :key_attributes,
  :key_check_value,
  :exportable,
  :enabled,
  :multi_region_key_type,
  :primary_region)
  SENSITIVE = []
  include Aws::Structure
end

#key_check_valueString

The key check value (KCV) is used to check if all parties holding a given key have the same key or to detect that a key has changed.

Returns:

  • (String)


2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2045

class KeySummary < Struct.new(
  :key_arn,
  :key_state,
  :key_attributes,
  :key_check_value,
  :exportable,
  :enabled,
  :multi_region_key_type,
  :primary_region)
  SENSITIVE = []
  include Aws::Structure
end

#key_stateString

The state of an Amazon Web Services Payment Cryptography that is being created or deleted.

Returns:

  • (String)


2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2045

class KeySummary < Struct.new(
  :key_arn,
  :key_state,
  :key_attributes,
  :key_check_value,
  :exportable,
  :enabled,
  :multi_region_key_type,
  :primary_region)
  SENSITIVE = []
  include Aws::Structure
end

#multi_region_key_typeString

Indicates whether this key is a Multi-Region key and its role in the Multi-Region key hierarchy.

Multi-Region replication keys allow the same key material to be used across multiple Amazon Web Services Regions. This field specifies whether the key is a Primary Region key (PRK) (which can be replicated to other Amazon Web Services Regions) or a Replica Region key (RRK) (which is a copy of a PRK in another Region). For more information, see [Multi-Region key replication].

[1]: docs.aws.amazon.com/payment-cryptography/latest/userguide/keys-multi-region-replication.html

Returns:

  • (String)


2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2045

class KeySummary < Struct.new(
  :key_arn,
  :key_state,
  :key_attributes,
  :key_check_value,
  :exportable,
  :enabled,
  :multi_region_key_type,
  :primary_region)
  SENSITIVE = []
  include Aws::Structure
end

#primary_regionString

An Amazon Web Services Region identifier in the standard format (e.g., ‘us-east-1`, `eu-west-1`).

Used to specify regions for key replication operations. The region must be a valid Amazon Web Services Region where Amazon Web Services Payment Cryptography is available.

Returns:

  • (String)


2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2045

class KeySummary < Struct.new(
  :key_arn,
  :key_state,
  :key_attributes,
  :key_check_value,
  :exportable,
  :enabled,
  :multi_region_key_type,
  :primary_region)
  SENSITIVE = []
  include Aws::Structure
end