Class: Aws::PaymentCryptography::Types::ListKeysInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-paymentcryptography/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#key_stateString

The key state of the keys you want to list.

Returns:

  • (String)


1933
1934
1935
1936
1937
1938
1939
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1933

class ListKeysInput < Struct.new(
  :key_state,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

Use this parameter to specify the maximum number of items to return. When this value is present, Amazon Web Services Payment Cryptography does not return more than the specified number of items, but it might return fewer.

This value is optional. If you include a value, it must be between 1 and 100, inclusive. If you do not include a value, it defaults to 50.

Returns:

  • (Integer)


1933
1934
1935
1936
1937
1938
1939
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1933

class ListKeysInput < Struct.new(
  :key_state,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Use this parameter in a subsequent request after you receive a response with truncated results. Set it to the value of NextToken from the truncated response you just received.

Returns:

  • (String)


1933
1934
1935
1936
1937
1938
1939
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1933

class ListKeysInput < Struct.new(
  :key_state,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end