Class: Aws::PaymentCryptography::Types::ListKeysOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::ListKeysOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#keys ⇒ Array<Types::KeySummary>
The list of keys created within the caller's Amazon Web Services account and Amazon Web Services Region.
-
#next_token ⇒ String
The token for the next set of results, or an empty or null value if there are no more results.
Instance Attribute Details
#keys ⇒ Array<Types::KeySummary>
The list of keys created within the caller's Amazon Web Services account and Amazon Web Services Region.
2151 2152 2153 2154 2155 2156 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2151 class ListKeysOutput < Struct.new( :keys, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or an empty or null value if there are no more results.
2151 2152 2153 2154 2155 2156 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2151 class ListKeysOutput < Struct.new( :keys, :next_token) SENSITIVE = [] include Aws::Structure end |