Class: Aws::PaymentCryptography::Types::PublicPolicyException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-paymentcryptography/types.rb

Overview

The resource-based policy would grant public access to the key.

Modify the policy to restrict access to specific principals and resubmit the request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


2269
2270
2271
2272
2273
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2269

class PublicPolicyException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end