Class: Aws::PaymentCryptography::Types::PutResourcePolicyInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::PutResourcePolicyInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy ⇒ String
The resource-based policy to attach to the key, in JSON format.
-
#resource_arn ⇒ String
The ‘KeyARN` of the key to attach the resource-based policy to.
Instance Attribute Details
#policy ⇒ String
The resource-based policy to attach to the key, in JSON format.
2285 2286 2287 2288 2289 2290 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2285 class PutResourcePolicyInput < Struct.new( :resource_arn, :policy) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The ‘KeyARN` of the key to attach the resource-based policy to.
2285 2286 2287 2288 2289 2290 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2285 class PutResourcePolicyInput < Struct.new( :resource_arn, :policy) SENSITIVE = [] include Aws::Structure end |