Class: Aws::PaymentCryptography::Types::RemoveKeyReplicationRegionsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::RemoveKeyReplicationRegionsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Input parameters for removing replication regions from a specific key.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key_identifier ⇒ String
The key identifier (ARN or alias) of the key from which to remove replication regions.
-
#replication_regions ⇒ Array<String>
The list of Amazon Web Services Regions to remove from the key’s replication configuration.
Instance Attribute Details
#key_identifier ⇒ String
The key identifier (ARN or alias) of the key from which to remove replication regions.
This key must exist and have replication enabled in the specified regions.
2331 2332 2333 2334 2335 2336 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2331 class RemoveKeyReplicationRegionsInput < Struct.new( :key_identifier, :replication_regions) SENSITIVE = [] include Aws::Structure end |
#replication_regions ⇒ Array<String>
The list of Amazon Web Services Regions to remove from the key’s replication configuration.
The key will no longer be available for cryptographic operations in these regions after removal. Ensure no active operations depend on the key in these regions before removal.
2331 2332 2333 2334 2335 2336 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2331 class RemoveKeyReplicationRegionsInput < Struct.new( :key_identifier, :replication_regions) SENSITIVE = [] include Aws::Structure end |