Class: Aws::PaymentCryptography::Types::RemoveKeyReplicationRegionsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::RemoveKeyReplicationRegionsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Output from removing replication regions from a key.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key ⇒ Types::Key
The updated key metadata after removing the replication regions.
Instance Attribute Details
#key ⇒ Types::Key
The updated key metadata after removing the replication regions.
This reflects the current state of the key and its updated replication configuration.
2349 2350 2351 2352 2353 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2349 class RemoveKeyReplicationRegionsOutput < Struct.new( :key) SENSITIVE = [] include Aws::Structure end |