Class: Aws::PaymentCryptography::Types::RootCertificatePublicKey
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::RootCertificatePublicKey
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Parameter information for root public key certificate import.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key_attributes ⇒ Types::KeyAttributes
The role of the key, the algorithm it supports, and the cryptographic operations allowed with the key.
-
#public_key_certificate ⇒ String
Parameter information for root public key certificate import.
Instance Attribute Details
#key_attributes ⇒ Types::KeyAttributes
The role of the key, the algorithm it supports, and the cryptographic operations allowed with the key. This data is immutable after the root public key is imported.
2466 2467 2468 2469 2470 2471 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2466 class RootCertificatePublicKey < Struct.new( :key_attributes, :public_key_certificate) SENSITIVE = [] include Aws::Structure end |
#public_key_certificate ⇒ String
Parameter information for root public key certificate import.
2466 2467 2468 2469 2470 2471 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2466 class RootCertificatePublicKey < Struct.new( :key_attributes, :public_key_certificate) SENSITIVE = [] include Aws::Structure end |