Class: Aws::PaymentCryptography::Types::StartKeyUsageOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::StartKeyUsageOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key ⇒ Types::Key
The
KeyARNof the Amazon Web Services Payment Cryptography key activated for use.
Instance Attribute Details
#key ⇒ Types::Key
The KeyARN of the Amazon Web Services Payment Cryptography key activated for use.
1474 1475 1476 1477 1478 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1474 class StartKeyUsageOutput < Struct.new( :key) SENSITIVE = [] include Aws::Structure end |