Class: Aws::PaymentCryptography::Types::UpdateAliasInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::UpdateAliasInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias_name ⇒ String
The alias whose associated key is changing.
-
#key_arn ⇒ String
The ‘KeyARN` for the key that you are updating or removing from the alias.
Instance Attribute Details
#alias_name ⇒ String
The alias whose associated key is changing.
2693 2694 2695 2696 2697 2698 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2693 class UpdateAliasInput < Struct.new( :alias_name, :key_arn) SENSITIVE = [] include Aws::Structure end |
#key_arn ⇒ String
The ‘KeyARN` for the key that you are updating or removing from the alias.
2693 2694 2695 2696 2697 2698 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2693 class UpdateAliasInput < Struct.new( :alias_name, :key_arn) SENSITIVE = [] include Aws::Structure end |