Class: Aws::PaymentCryptography::Types::ValidationException
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::ValidationException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
The request was denied due to an invalid request error.
One or more parameters in your request are invalid. Check the parameter values, formats, and constraints specified in the API documentation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
2731 2732 2733 2734 2735 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2731 class ValidationException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |