Module: Aws::PaymentCryptography::Types
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Defined Under Namespace
Classes: AccessDeniedException, AddKeyReplicationRegionsInput, AddKeyReplicationRegionsOutput, Alias, AssociateMpaTeamInput, AssociateMpaTeamOutput, CertificateSubjectType, ConflictException, CreateAliasInput, CreateAliasOutput, CreateKeyInput, CreateKeyOutput, DeleteAliasInput, DeleteAliasOutput, DeleteKeyInput, DeleteKeyOutput, DeleteResourcePolicyInput, DeleteResourcePolicyOutput, DiffieHellmanDerivationData, DisableDefaultKeyReplicationRegionsInput, DisableDefaultKeyReplicationRegionsOutput, DisassociateMpaTeamInput, DisassociateMpaTeamOutput, EnableDefaultKeyReplicationRegionsInput, EnableDefaultKeyReplicationRegionsOutput, ExportAs2805KeyCryptogram, ExportAttributes, ExportDiffieHellmanTr31KeyBlock, ExportDukptInitialKey, ExportKeyCryptogram, ExportKeyInput, ExportKeyMaterial, ExportKeyOutput, ExportTr31KeyBlock, ExportTr34KeyBlock, GetAliasInput, GetAliasOutput, GetCertificateSigningRequestInput, GetCertificateSigningRequestOutput, GetDefaultKeyReplicationRegionsInput, GetDefaultKeyReplicationRegionsOutput, GetKeyInput, GetKeyOutput, GetMpaTeamAssociationInput, GetMpaTeamAssociationOutput, GetParametersForExportInput, GetParametersForExportOutput, GetParametersForImportInput, GetParametersForImportOutput, GetPublicKeyCertificateInput, GetPublicKeyCertificateOutput, GetResourcePolicyInput, GetResourcePolicyOutput, ImportAs2805KeyCryptogram, ImportDiffieHellmanTr31KeyBlock, ImportKeyCryptogram, ImportKeyInput, ImportKeyMaterial, ImportKeyOutput, ImportTr31KeyBlock, ImportTr34KeyBlock, InternalServerException, Key, KeyAttributes, KeyBlockHeaders, KeyModesOfUse, KeySummary, ListAliasesInput, ListAliasesOutput, ListKeysInput, ListKeysOutput, ListTagsForResourceInput, ListTagsForResourceOutput, MpaStatus, MpaTeamAssociation, PublicPolicyException, PutResourcePolicyInput, PutResourcePolicyOutput, RemoveKeyReplicationRegionsInput, RemoveKeyReplicationRegionsOutput, ReplicationStatusType, ResourceNotFoundException, RestoreKeyInput, RestoreKeyOutput, RootCertificatePublicKey, ServiceQuotaExceededException, ServiceUnavailableException, StartKeyUsageInput, StartKeyUsageOutput, StopKeyUsageInput, StopKeyUsageOutput, Tag, TagResourceInput, TagResourceOutput, ThrottlingException, TrustedCertificatePublicKey, UntagResourceInput, UntagResourceOutput, UpdateAliasInput, UpdateAliasOutput, ValidationException, WrappedKey
Instance Attribute Summary collapse
-
#as_2805_key_cryptogram ⇒ Types::ImportAs2805KeyCryptogram
Parameter information for key material import using AS2805 key cryptogram format.
-
#diffie_hellman_tr_31_key_block ⇒ Types::ImportDiffieHellmanTr31KeyBlock
Key derivation parameter information for key material import using asymmetric ECDH key exchange method.
-
#key_cryptogram ⇒ Types::ImportKeyCryptogram
Parameter information for key material import using asymmetric RSA wrap and unwrap key exchange method.
-
#root_certificate_public_key ⇒ Types::RootCertificatePublicKey
Parameter information for root public key certificate import.
-
#shared_information ⇒ String
A string containing information that binds the ECDH derived key to the two parties involved or to the context of the key.
-
#tr_31_key_block ⇒ Types::ImportTr31KeyBlock
Parameter information for key material import using symmetric TR-31 key exchange method.
-
#tr_34_key_block ⇒ Types::ImportTr34KeyBlock
Parameter information for key material import using the asymmetric TR-34 key exchange method.
-
#trusted_certificate_public_key ⇒ Types::TrustedCertificatePublicKey
Parameter information for trusted public key certificate import.
Instance Attribute Details
#as_2805_key_cryptogram ⇒ Types::ImportAs2805KeyCryptogram
Parameter information for key material import using AS2805 key cryptogram format.
766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 766 class ExportKeyMaterial < Struct.new( :tr_31_key_block, :tr_34_key_block, :key_cryptogram, :diffie_hellman_tr_31_key_block, :as_2805_key_cryptogram, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Tr31KeyBlock < ExportKeyMaterial; end class Tr34KeyBlock < ExportKeyMaterial; end class KeyCryptogram < ExportKeyMaterial; end class DiffieHellmanTr31KeyBlock < ExportKeyMaterial; end class As2805KeyCryptogram < ExportKeyMaterial; end class Unknown < ExportKeyMaterial; end end |
#diffie_hellman_tr_31_key_block ⇒ Types::ImportDiffieHellmanTr31KeyBlock
Key derivation parameter information for key material import using asymmetric ECDH key exchange method.
766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 766 class ExportKeyMaterial < Struct.new( :tr_31_key_block, :tr_34_key_block, :key_cryptogram, :diffie_hellman_tr_31_key_block, :as_2805_key_cryptogram, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Tr31KeyBlock < ExportKeyMaterial; end class Tr34KeyBlock < ExportKeyMaterial; end class KeyCryptogram < ExportKeyMaterial; end class DiffieHellmanTr31KeyBlock < ExportKeyMaterial; end class As2805KeyCryptogram < ExportKeyMaterial; end class Unknown < ExportKeyMaterial; end end |
#key_cryptogram ⇒ Types::ImportKeyCryptogram
Parameter information for key material import using asymmetric RSA wrap and unwrap key exchange method.
766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 766 class ExportKeyMaterial < Struct.new( :tr_31_key_block, :tr_34_key_block, :key_cryptogram, :diffie_hellman_tr_31_key_block, :as_2805_key_cryptogram, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Tr31KeyBlock < ExportKeyMaterial; end class Tr34KeyBlock < ExportKeyMaterial; end class KeyCryptogram < ExportKeyMaterial; end class DiffieHellmanTr31KeyBlock < ExportKeyMaterial; end class As2805KeyCryptogram < ExportKeyMaterial; end class Unknown < ExportKeyMaterial; end end |
#root_certificate_public_key ⇒ Types::RootCertificatePublicKey
Parameter information for root public key certificate import.
1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1514 class ImportKeyMaterial < Struct.new( :root_certificate_public_key, :trusted_certificate_public_key, :tr_31_key_block, :tr_34_key_block, :key_cryptogram, :diffie_hellman_tr_31_key_block, :as_2805_key_cryptogram, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RootCertificatePublicKey < ImportKeyMaterial; end class TrustedCertificatePublicKey < ImportKeyMaterial; end class Tr31KeyBlock < ImportKeyMaterial; end class Tr34KeyBlock < ImportKeyMaterial; end class KeyCryptogram < ImportKeyMaterial; end class DiffieHellmanTr31KeyBlock < ImportKeyMaterial; end class As2805KeyCryptogram < ImportKeyMaterial; end class Unknown < ImportKeyMaterial; end end |
#shared_information ⇒ String
A string containing information that binds the ECDH derived key to the two parties involved or to the context of the key.
It may include details like identities of the two parties deriving the key, context of the operation, session IDs, and optionally a nonce. It must not contain zero bytes. It is not recommended to reuse shared information for multiple ECDH key derivations, as it could result in derived key material being the same across different derivations.
423 424 425 426 427 428 429 430 431 432 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 423 class DiffieHellmanDerivationData < Struct.new( :shared_information, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class SharedInformation < DiffieHellmanDerivationData; end class Unknown < DiffieHellmanDerivationData; end end |
#tr_31_key_block ⇒ Types::ImportTr31KeyBlock
Parameter information for key material import using symmetric TR-31 key exchange method.
766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 766 class ExportKeyMaterial < Struct.new( :tr_31_key_block, :tr_34_key_block, :key_cryptogram, :diffie_hellman_tr_31_key_block, :as_2805_key_cryptogram, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Tr31KeyBlock < ExportKeyMaterial; end class Tr34KeyBlock < ExportKeyMaterial; end class KeyCryptogram < ExportKeyMaterial; end class DiffieHellmanTr31KeyBlock < ExportKeyMaterial; end class As2805KeyCryptogram < ExportKeyMaterial; end class Unknown < ExportKeyMaterial; end end |
#tr_34_key_block ⇒ Types::ImportTr34KeyBlock
Parameter information for key material import using the asymmetric TR-34 key exchange method.
766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 766 class ExportKeyMaterial < Struct.new( :tr_31_key_block, :tr_34_key_block, :key_cryptogram, :diffie_hellman_tr_31_key_block, :as_2805_key_cryptogram, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Tr31KeyBlock < ExportKeyMaterial; end class Tr34KeyBlock < ExportKeyMaterial; end class KeyCryptogram < ExportKeyMaterial; end class DiffieHellmanTr31KeyBlock < ExportKeyMaterial; end class As2805KeyCryptogram < ExportKeyMaterial; end class Unknown < ExportKeyMaterial; end end |
#trusted_certificate_public_key ⇒ Types::TrustedCertificatePublicKey
Parameter information for trusted public key certificate import.
1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1514 class ImportKeyMaterial < Struct.new( :root_certificate_public_key, :trusted_certificate_public_key, :tr_31_key_block, :tr_34_key_block, :key_cryptogram, :diffie_hellman_tr_31_key_block, :as_2805_key_cryptogram, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RootCertificatePublicKey < ImportKeyMaterial; end class TrustedCertificatePublicKey < ImportKeyMaterial; end class Tr31KeyBlock < ImportKeyMaterial; end class Tr34KeyBlock < ImportKeyMaterial; end class KeyCryptogram < ImportKeyMaterial; end class DiffieHellmanTr31KeyBlock < ImportKeyMaterial; end class As2805KeyCryptogram < ImportKeyMaterial; end class Unknown < ImportKeyMaterial; end end |