Class: Aws::PaymentCryptography::Types::AssociateMpaTeamInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::AssociateMpaTeamInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:requester_comment]
Instance Attribute Summary collapse
-
#action ⇒ String
The protected operation to associate with the MPA team.
-
#mpa_team_arn ⇒ String
The ARN of the MPA team to associate with the protected operation.
-
#requester_comment ⇒ String
The comment from the requester explaining the reason for the association.
Instance Attribute Details
#action ⇒ String
The protected operation to associate with the MPA team. Currently, the only supported value is ‘IMPORT_ROOT_PUBLIC_KEY_CERTIFICATE`.
121 122 123 124 125 126 127 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 121 class AssociateMpaTeamInput < Struct.new( :action, :mpa_team_arn, :requester_comment) SENSITIVE = [:requester_comment] include Aws::Structure end |
#mpa_team_arn ⇒ String
The ARN of the MPA team to associate with the protected operation.
121 122 123 124 125 126 127 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 121 class AssociateMpaTeamInput < Struct.new( :action, :mpa_team_arn, :requester_comment) SENSITIVE = [:requester_comment] include Aws::Structure end |
#requester_comment ⇒ String
The comment from the requester explaining the reason for the association.
Don’t include personal, confidential or sensitive information in this field. This field may be displayed in plaintext in CloudTrail logs and other output.
121 122 123 124 125 126 127 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 121 class AssociateMpaTeamInput < Struct.new( :action, :mpa_team_arn, :requester_comment) SENSITIVE = [:requester_comment] include Aws::Structure end |