Class: Aws::PaymentCryptography::Types::DisassociateMpaTeamInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::DisassociateMpaTeamInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:requester_comment]
Instance Attribute Summary collapse
-
#action ⇒ String
The protected operation to disassociate from the MPA team.
-
#requester_comment ⇒ String
The comment from the requester explaining the reason for the disassociation.
Instance Attribute Details
#action ⇒ String
The protected operation to disassociate from the MPA team. Currently, the only supported value is ‘IMPORT_ROOT_PUBLIC_KEY_CERTIFICATE`.
489 490 491 492 493 494 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 489 class DisassociateMpaTeamInput < Struct.new( :action, :requester_comment) SENSITIVE = [:requester_comment] include Aws::Structure end |
#requester_comment ⇒ String
The comment from the requester explaining the reason for the disassociation.
Don’t include personal, confidential or sensitive information in this field. This field may be displayed in plaintext in CloudTrail logs and other output.
489 490 491 492 493 494 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 489 class DisassociateMpaTeamInput < Struct.new( :action, :requester_comment) SENSITIVE = [:requester_comment] include Aws::Structure end |