Class: Aws::PaymentCryptography::Types::EnableDefaultKeyReplicationRegionsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::EnableDefaultKeyReplicationRegionsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Input parameters for enabling default key replication regions for the account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#replication_regions ⇒ Array<String>
The list of Amazon Web Services Regions to enable as default replication regions for the Amazon Web Services account for [Multi-Region key replication].
Instance Attribute Details
#replication_regions ⇒ Array<String>
The list of Amazon Web Services Regions to enable as default replication regions for the Amazon Web Services account for [Multi-Region key replication].
New keys created in this account will automatically be replicated to these regions unless explicitly overridden during key creation.
[1]: docs.aws.amazon.com/payment-cryptography/latest/userguide/keys-multi-region-replication.html
433 434 435 436 437 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 433 class EnableDefaultKeyReplicationRegionsInput < Struct.new( :replication_regions) SENSITIVE = [] include Aws::Structure end |