Class: Aws::PaymentCryptography::Types::ExportDiffieHellmanTr31KeyBlock

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-paymentcryptography/types.rb

Overview

Key derivation parameter information for key material export using asymmetric ECDH key exchange method.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_authority_public_key_identifierString

The ‘keyARN` of the CA that signed the `PublicKeyCertificate` for the client’s receiving ECC key pair.

Returns:

  • (String)


650
651
652
653
654
655
656
657
658
659
660
661
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 650

class ExportDiffieHellmanTr31KeyBlock < Struct.new(
  :private_key_identifier,
  :certificate_authority_public_key_identifier,
  :public_key_certificate,
  :derive_key_algorithm,
  :key_derivation_function,
  :key_derivation_hash_algorithm,
  :derivation_data,
  :key_block_headers)
  SENSITIVE = []
  include Aws::Structure
end

#derivation_dataTypes::DiffieHellmanDerivationData

The shared information used when deriving a key using ECDH.



650
651
652
653
654
655
656
657
658
659
660
661
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 650

class ExportDiffieHellmanTr31KeyBlock < Struct.new(
  :private_key_identifier,
  :certificate_authority_public_key_identifier,
  :public_key_certificate,
  :derive_key_algorithm,
  :key_derivation_function,
  :key_derivation_hash_algorithm,
  :derivation_data,
  :key_block_headers)
  SENSITIVE = []
  include Aws::Structure
end

#derive_key_algorithmString

The key algorithm of the shared derived ECDH key.

Returns:

  • (String)


650
651
652
653
654
655
656
657
658
659
660
661
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 650

class ExportDiffieHellmanTr31KeyBlock < Struct.new(
  :private_key_identifier,
  :certificate_authority_public_key_identifier,
  :public_key_certificate,
  :derive_key_algorithm,
  :key_derivation_function,
  :key_derivation_hash_algorithm,
  :derivation_data,
  :key_block_headers)
  SENSITIVE = []
  include Aws::Structure
end

#key_block_headersTypes::KeyBlockHeaders

Optional metadata for export associated with the key material. This data is signed but transmitted in clear text.



650
651
652
653
654
655
656
657
658
659
660
661
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 650

class ExportDiffieHellmanTr31KeyBlock < Struct.new(
  :private_key_identifier,
  :certificate_authority_public_key_identifier,
  :public_key_certificate,
  :derive_key_algorithm,
  :key_derivation_function,
  :key_derivation_hash_algorithm,
  :derivation_data,
  :key_block_headers)
  SENSITIVE = []
  include Aws::Structure
end

#key_derivation_functionString

The key derivation function to use when deriving a key using ECDH.

Returns:

  • (String)


650
651
652
653
654
655
656
657
658
659
660
661
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 650

class ExportDiffieHellmanTr31KeyBlock < Struct.new(
  :private_key_identifier,
  :certificate_authority_public_key_identifier,
  :public_key_certificate,
  :derive_key_algorithm,
  :key_derivation_function,
  :key_derivation_hash_algorithm,
  :derivation_data,
  :key_block_headers)
  SENSITIVE = []
  include Aws::Structure
end

#key_derivation_hash_algorithmString

The hash type to use when deriving a key using ECDH.

Returns:

  • (String)


650
651
652
653
654
655
656
657
658
659
660
661
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 650

class ExportDiffieHellmanTr31KeyBlock < Struct.new(
  :private_key_identifier,
  :certificate_authority_public_key_identifier,
  :public_key_certificate,
  :derive_key_algorithm,
  :key_derivation_function,
  :key_derivation_hash_algorithm,
  :derivation_data,
  :key_block_headers)
  SENSITIVE = []
  include Aws::Structure
end

#private_key_identifierString

The ‘keyARN` of the asymmetric ECC key created within Amazon Web Services Payment Cryptography.

Returns:

  • (String)


650
651
652
653
654
655
656
657
658
659
660
661
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 650

class ExportDiffieHellmanTr31KeyBlock < Struct.new(
  :private_key_identifier,
  :certificate_authority_public_key_identifier,
  :public_key_certificate,
  :derive_key_algorithm,
  :key_derivation_function,
  :key_derivation_hash_algorithm,
  :derivation_data,
  :key_block_headers)
  SENSITIVE = []
  include Aws::Structure
end

#public_key_certificateString

The public key certificate of the client’s receiving ECC key pair, in PEM format (base64 encoded), to use for ECDH key derivation.

Returns:

  • (String)


650
651
652
653
654
655
656
657
658
659
660
661
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 650

class ExportDiffieHellmanTr31KeyBlock < Struct.new(
  :private_key_identifier,
  :certificate_authority_public_key_identifier,
  :public_key_certificate,
  :derive_key_algorithm,
  :key_derivation_function,
  :key_derivation_hash_algorithm,
  :derivation_data,
  :key_block_headers)
  SENSITIVE = []
  include Aws::Structure
end