Class: Aws::PaymentCryptography::Types::ExportDiffieHellmanTr31KeyBlock
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::ExportDiffieHellmanTr31KeyBlock
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Key derivation parameter information for key material export using asymmetric ECDH key exchange method.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_authority_public_key_identifier ⇒ String
The ‘keyARN` of the CA that signed the `PublicKeyCertificate` for the client’s receiving ECC key pair.
-
#derivation_data ⇒ Types::DiffieHellmanDerivationData
The shared information used when deriving a key using ECDH.
-
#derive_key_algorithm ⇒ String
The key algorithm of the shared derived ECDH key.
-
#key_block_headers ⇒ Types::KeyBlockHeaders
Optional metadata for export associated with the key material.
-
#key_derivation_function ⇒ String
The key derivation function to use when deriving a key using ECDH.
-
#key_derivation_hash_algorithm ⇒ String
The hash type to use when deriving a key using ECDH.
-
#private_key_identifier ⇒ String
The ‘keyARN` of the asymmetric ECC key created within Amazon Web Services Payment Cryptography.
-
#public_key_certificate ⇒ String
The public key certificate of the client’s receiving ECC key pair, in PEM format (base64 encoded), to use for ECDH key derivation.
Instance Attribute Details
#certificate_authority_public_key_identifier ⇒ String
The ‘keyARN` of the CA that signed the `PublicKeyCertificate` for the client’s receiving ECC key pair.
650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 650 class ExportDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :key_block_headers) SENSITIVE = [] include Aws::Structure end |
#derivation_data ⇒ Types::DiffieHellmanDerivationData
The shared information used when deriving a key using ECDH.
650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 650 class ExportDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :key_block_headers) SENSITIVE = [] include Aws::Structure end |
#derive_key_algorithm ⇒ String
The key algorithm of the shared derived ECDH key.
650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 650 class ExportDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :key_block_headers) SENSITIVE = [] include Aws::Structure end |
#key_block_headers ⇒ Types::KeyBlockHeaders
Optional metadata for export associated with the key material. This data is signed but transmitted in clear text.
650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 650 class ExportDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :key_block_headers) SENSITIVE = [] include Aws::Structure end |
#key_derivation_function ⇒ String
The key derivation function to use when deriving a key using ECDH.
650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 650 class ExportDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :key_block_headers) SENSITIVE = [] include Aws::Structure end |
#key_derivation_hash_algorithm ⇒ String
The hash type to use when deriving a key using ECDH.
650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 650 class ExportDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :key_block_headers) SENSITIVE = [] include Aws::Structure end |
#private_key_identifier ⇒ String
The ‘keyARN` of the asymmetric ECC key created within Amazon Web Services Payment Cryptography.
650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 650 class ExportDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :key_block_headers) SENSITIVE = [] include Aws::Structure end |
#public_key_certificate ⇒ String
The public key certificate of the client’s receiving ECC key pair, in PEM format (base64 encoded), to use for ECDH key derivation.
650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 650 class ExportDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :key_block_headers) SENSITIVE = [] include Aws::Structure end |