Class: Aws::PaymentCryptography::Types::ExportKeyCryptogram
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::ExportKeyCryptogram
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Parameter information for key material export using asymmetric RSA wrap and unwrap key exchange method.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_authority_public_key_identifier ⇒ String
The ‘KeyARN` of the certificate chain that signs the wrapping key certificate during RSA wrap and unwrap key export.
-
#wrapping_key_certificate ⇒ String
The wrapping key certificate in PEM format (base64 encoded).
-
#wrapping_spec ⇒ String
The wrapping spec for the key under export.
Instance Attribute Details
#certificate_authority_public_key_identifier ⇒ String
The ‘KeyARN` of the certificate chain that signs the wrapping key certificate during RSA wrap and unwrap key export.
701 702 703 704 705 706 707 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 701 class ExportKeyCryptogram < Struct.new( :certificate_authority_public_key_identifier, :wrapping_key_certificate, :wrapping_spec) SENSITIVE = [] include Aws::Structure end |
#wrapping_key_certificate ⇒ String
The wrapping key certificate in PEM format (base64 encoded). Amazon Web Services Payment Cryptography uses this certificate to wrap the key under export.
701 702 703 704 705 706 707 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 701 class ExportKeyCryptogram < Struct.new( :certificate_authority_public_key_identifier, :wrapping_key_certificate, :wrapping_spec) SENSITIVE = [] include Aws::Structure end |
#wrapping_spec ⇒ String
The wrapping spec for the key under export.
701 702 703 704 705 706 707 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 701 class ExportKeyCryptogram < Struct.new( :certificate_authority_public_key_identifier, :wrapping_key_certificate, :wrapping_spec) SENSITIVE = [] include Aws::Structure end |