Class: Aws::PaymentCryptography::Types::ExportKeyMaterial

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-paymentcryptography/types.rb

Overview

Note:

ExportKeyMaterial is a union - when making an API calls you must set exactly one of the members.

Parameter information for key material export from Amazon Web Services Payment Cryptography using TR-31 or TR-34 or RSA wrap and unwrap key exchange method.

Defined Under Namespace

Classes: As2805KeyCryptogram, DiffieHellmanTr31KeyBlock, KeyCryptogram, Tr31KeyBlock, Tr34KeyBlock, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#as_2805_key_cryptogramTypes::ExportAs2805KeyCryptogram

Parameter information for key material export using AS2805 key cryptogram format.



770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 770

class ExportKeyMaterial < Struct.new(
  :tr_31_key_block,
  :tr_34_key_block,
  :key_cryptogram,
  :diffie_hellman_tr_31_key_block,
  :as_2805_key_cryptogram,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Tr31KeyBlock < ExportKeyMaterial; end
  class Tr34KeyBlock < ExportKeyMaterial; end
  class KeyCryptogram < ExportKeyMaterial; end
  class DiffieHellmanTr31KeyBlock < ExportKeyMaterial; end
  class As2805KeyCryptogram < ExportKeyMaterial; end
  class Unknown < ExportKeyMaterial; end
end

#diffie_hellman_tr_31_key_blockTypes::ExportDiffieHellmanTr31KeyBlock

Key derivation parameter information for key material export using asymmetric ECDH key exchange method.



770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 770

class ExportKeyMaterial < Struct.new(
  :tr_31_key_block,
  :tr_34_key_block,
  :key_cryptogram,
  :diffie_hellman_tr_31_key_block,
  :as_2805_key_cryptogram,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Tr31KeyBlock < ExportKeyMaterial; end
  class Tr34KeyBlock < ExportKeyMaterial; end
  class KeyCryptogram < ExportKeyMaterial; end
  class DiffieHellmanTr31KeyBlock < ExportKeyMaterial; end
  class As2805KeyCryptogram < ExportKeyMaterial; end
  class Unknown < ExportKeyMaterial; end
end

#key_cryptogramTypes::ExportKeyCryptogram

Parameter information for key material export using asymmetric RSA wrap and unwrap key exchange method



770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 770

class ExportKeyMaterial < Struct.new(
  :tr_31_key_block,
  :tr_34_key_block,
  :key_cryptogram,
  :diffie_hellman_tr_31_key_block,
  :as_2805_key_cryptogram,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Tr31KeyBlock < ExportKeyMaterial; end
  class Tr34KeyBlock < ExportKeyMaterial; end
  class KeyCryptogram < ExportKeyMaterial; end
  class DiffieHellmanTr31KeyBlock < ExportKeyMaterial; end
  class As2805KeyCryptogram < ExportKeyMaterial; end
  class Unknown < ExportKeyMaterial; end
end

#tr_31_key_blockTypes::ExportTr31KeyBlock

Parameter information for key material export using symmetric TR-31 key exchange method.



770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 770

class ExportKeyMaterial < Struct.new(
  :tr_31_key_block,
  :tr_34_key_block,
  :key_cryptogram,
  :diffie_hellman_tr_31_key_block,
  :as_2805_key_cryptogram,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Tr31KeyBlock < ExportKeyMaterial; end
  class Tr34KeyBlock < ExportKeyMaterial; end
  class KeyCryptogram < ExportKeyMaterial; end
  class DiffieHellmanTr31KeyBlock < ExportKeyMaterial; end
  class As2805KeyCryptogram < ExportKeyMaterial; end
  class Unknown < ExportKeyMaterial; end
end

#tr_34_key_blockTypes::ExportTr34KeyBlock

Parameter information for key material export using the asymmetric TR-34 key exchange method.



770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 770

class ExportKeyMaterial < Struct.new(
  :tr_31_key_block,
  :tr_34_key_block,
  :key_cryptogram,
  :diffie_hellman_tr_31_key_block,
  :as_2805_key_cryptogram,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Tr31KeyBlock < ExportKeyMaterial; end
  class Tr34KeyBlock < ExportKeyMaterial; end
  class KeyCryptogram < ExportKeyMaterial; end
  class DiffieHellmanTr31KeyBlock < ExportKeyMaterial; end
  class As2805KeyCryptogram < ExportKeyMaterial; end
  class Unknown < ExportKeyMaterial; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



770
771
772
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 770

def unknown
  @unknown
end