Class: Aws::PaymentCryptography::Types::ExportKeyMaterial
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::ExportKeyMaterial
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
ExportKeyMaterial is a union - when making an API calls you must set exactly one of the members.
Parameter information for key material export from Amazon Web Services Payment Cryptography using TR-31 or TR-34 or RSA wrap and unwrap key exchange method.
Direct Known Subclasses
As2805KeyCryptogram, DiffieHellmanTr31KeyBlock, KeyCryptogram, Tr31KeyBlock, Tr34KeyBlock, Unknown
Defined Under Namespace
Classes: As2805KeyCryptogram, DiffieHellmanTr31KeyBlock, KeyCryptogram, Tr31KeyBlock, Tr34KeyBlock, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#as_2805_key_cryptogram ⇒ Types::ExportAs2805KeyCryptogram
Parameter information for key material export using AS2805 key cryptogram format.
-
#diffie_hellman_tr_31_key_block ⇒ Types::ExportDiffieHellmanTr31KeyBlock
Key derivation parameter information for key material export using asymmetric ECDH key exchange method.
-
#key_cryptogram ⇒ Types::ExportKeyCryptogram
Parameter information for key material export using asymmetric RSA wrap and unwrap key exchange method.
-
#tr_31_key_block ⇒ Types::ExportTr31KeyBlock
Parameter information for key material export using symmetric TR-31 key exchange method.
-
#tr_34_key_block ⇒ Types::ExportTr34KeyBlock
Parameter information for key material export using the asymmetric TR-34 key exchange method.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#as_2805_key_cryptogram ⇒ Types::ExportAs2805KeyCryptogram
Parameter information for key material export using AS2805 key cryptogram format.
766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 766 class ExportKeyMaterial < Struct.new( :tr_31_key_block, :tr_34_key_block, :key_cryptogram, :diffie_hellman_tr_31_key_block, :as_2805_key_cryptogram, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Tr31KeyBlock < ExportKeyMaterial; end class Tr34KeyBlock < ExportKeyMaterial; end class KeyCryptogram < ExportKeyMaterial; end class DiffieHellmanTr31KeyBlock < ExportKeyMaterial; end class As2805KeyCryptogram < ExportKeyMaterial; end class Unknown < ExportKeyMaterial; end end |
#diffie_hellman_tr_31_key_block ⇒ Types::ExportDiffieHellmanTr31KeyBlock
Key derivation parameter information for key material export using asymmetric ECDH key exchange method.
766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 766 class ExportKeyMaterial < Struct.new( :tr_31_key_block, :tr_34_key_block, :key_cryptogram, :diffie_hellman_tr_31_key_block, :as_2805_key_cryptogram, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Tr31KeyBlock < ExportKeyMaterial; end class Tr34KeyBlock < ExportKeyMaterial; end class KeyCryptogram < ExportKeyMaterial; end class DiffieHellmanTr31KeyBlock < ExportKeyMaterial; end class As2805KeyCryptogram < ExportKeyMaterial; end class Unknown < ExportKeyMaterial; end end |
#key_cryptogram ⇒ Types::ExportKeyCryptogram
Parameter information for key material export using asymmetric RSA wrap and unwrap key exchange method
766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 766 class ExportKeyMaterial < Struct.new( :tr_31_key_block, :tr_34_key_block, :key_cryptogram, :diffie_hellman_tr_31_key_block, :as_2805_key_cryptogram, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Tr31KeyBlock < ExportKeyMaterial; end class Tr34KeyBlock < ExportKeyMaterial; end class KeyCryptogram < ExportKeyMaterial; end class DiffieHellmanTr31KeyBlock < ExportKeyMaterial; end class As2805KeyCryptogram < ExportKeyMaterial; end class Unknown < ExportKeyMaterial; end end |
#tr_31_key_block ⇒ Types::ExportTr31KeyBlock
Parameter information for key material export using symmetric TR-31 key exchange method.
766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 766 class ExportKeyMaterial < Struct.new( :tr_31_key_block, :tr_34_key_block, :key_cryptogram, :diffie_hellman_tr_31_key_block, :as_2805_key_cryptogram, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Tr31KeyBlock < ExportKeyMaterial; end class Tr34KeyBlock < ExportKeyMaterial; end class KeyCryptogram < ExportKeyMaterial; end class DiffieHellmanTr31KeyBlock < ExportKeyMaterial; end class As2805KeyCryptogram < ExportKeyMaterial; end class Unknown < ExportKeyMaterial; end end |
#tr_34_key_block ⇒ Types::ExportTr34KeyBlock
Parameter information for key material export using the asymmetric TR-34 key exchange method.
766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 766 class ExportKeyMaterial < Struct.new( :tr_31_key_block, :tr_34_key_block, :key_cryptogram, :diffie_hellman_tr_31_key_block, :as_2805_key_cryptogram, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Tr31KeyBlock < ExportKeyMaterial; end class Tr34KeyBlock < ExportKeyMaterial; end class KeyCryptogram < ExportKeyMaterial; end class DiffieHellmanTr31KeyBlock < ExportKeyMaterial; end class As2805KeyCryptogram < ExportKeyMaterial; end class Unknown < ExportKeyMaterial; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
766 767 768 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 766 def unknown @unknown end |