Class: Aws::PaymentCryptography::Types::ExportTr34KeyBlock
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::ExportTr34KeyBlock
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Parameter information for key material export using the asymmetric TR-34 key exchange method.
Constant Summary collapse
- SENSITIVE =
[:wrapping_key_certificate]
Instance Attribute Summary collapse
-
#certificate_authority_public_key_identifier ⇒ String
The
KeyARNof the certificate chain that signs the wrapping key certificate during TR-34 key export. -
#export_token ⇒ String
The export token to initiate key export from Amazon Web Services Payment Cryptography.
-
#key_block_format ⇒ String
The format of key block that Amazon Web Services Payment Cryptography will use during key export.
-
#key_block_headers ⇒ Types::KeyBlockHeaders
Optional metadata for export associated with the key material.
-
#random_nonce ⇒ String
A random number value that is unique to the TR-34 key block generated using 2 pass.
-
#wrapping_key_certificate ⇒ String
The
KeyARNof the wrapping key certificate.
Instance Attribute Details
#certificate_authority_public_key_identifier ⇒ String
The KeyARN of the certificate chain that signs the wrapping key certificate during TR-34 key export.
441 442 443 444 445 446 447 448 449 450 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 441 class ExportTr34KeyBlock < Struct.new( :certificate_authority_public_key_identifier, :wrapping_key_certificate, :export_token, :key_block_format, :random_nonce, :key_block_headers) SENSITIVE = [:wrapping_key_certificate] include Aws::Structure end |
#export_token ⇒ String
The export token to initiate key export from Amazon Web Services Payment Cryptography. It also contains the signing key certificate that will sign the wrapped key during TR-34 key block generation. Call [GetParametersForExport] to receive an export token. It expires after 7 days. You can use the same export token to export multiple keys from the same service account.
[1]: docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_GetParametersForExport.html
441 442 443 444 445 446 447 448 449 450 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 441 class ExportTr34KeyBlock < Struct.new( :certificate_authority_public_key_identifier, :wrapping_key_certificate, :export_token, :key_block_format, :random_nonce, :key_block_headers) SENSITIVE = [:wrapping_key_certificate] include Aws::Structure end |
#key_block_format ⇒ String
The format of key block that Amazon Web Services Payment Cryptography will use during key export.
441 442 443 444 445 446 447 448 449 450 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 441 class ExportTr34KeyBlock < Struct.new( :certificate_authority_public_key_identifier, :wrapping_key_certificate, :export_token, :key_block_format, :random_nonce, :key_block_headers) SENSITIVE = [:wrapping_key_certificate] include Aws::Structure end |
#key_block_headers ⇒ Types::KeyBlockHeaders
Optional metadata for export associated with the key material. This data is signed but transmitted in clear text.
441 442 443 444 445 446 447 448 449 450 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 441 class ExportTr34KeyBlock < Struct.new( :certificate_authority_public_key_identifier, :wrapping_key_certificate, :export_token, :key_block_format, :random_nonce, :key_block_headers) SENSITIVE = [:wrapping_key_certificate] include Aws::Structure end |
#random_nonce ⇒ String
A random number value that is unique to the TR-34 key block generated using 2 pass. The operation will fail, if a random nonce value is not provided for a TR-34 key block generated using 2 pass.
441 442 443 444 445 446 447 448 449 450 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 441 class ExportTr34KeyBlock < Struct.new( :certificate_authority_public_key_identifier, :wrapping_key_certificate, :export_token, :key_block_format, :random_nonce, :key_block_headers) SENSITIVE = [:wrapping_key_certificate] include Aws::Structure end |
#wrapping_key_certificate ⇒ String
The KeyARN of the wrapping key certificate. Amazon Web Services Payment Cryptography uses this certificate to wrap the key under export.
441 442 443 444 445 446 447 448 449 450 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 441 class ExportTr34KeyBlock < Struct.new( :certificate_authority_public_key_identifier, :wrapping_key_certificate, :export_token, :key_block_format, :random_nonce, :key_block_headers) SENSITIVE = [:wrapping_key_certificate] include Aws::Structure end |