Class: Aws::PaymentCryptography::Types::GetDefaultKeyReplicationRegionsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::GetDefaultKeyReplicationRegionsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Output containing the account’s current default key replication configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled_replication_regions ⇒ Array<String>
The list of regions where default key replication is currently enabled for the account.
Instance Attribute Details
#enabled_replication_regions ⇒ Array<String>
The list of regions where default key replication is currently enabled for the account.
New keys created in this account will automatically be replicated to these regions unless explicitly configured otherwise during key creation.
968 969 970 971 972 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 968 class GetDefaultKeyReplicationRegionsOutput < Struct.new( :enabled_replication_regions) SENSITIVE = [] include Aws::Structure end |