Class: Aws::PaymentCryptography::Types::GetParametersForExportOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::GetParametersForExportOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#export_token ⇒ String
The export token to initiate key export from Amazon Web Services Payment Cryptography.
-
#parameters_valid_until_timestamp ⇒ Time
The validity period of the export token.
-
#signing_key_algorithm ⇒ String
The algorithm of the signing key certificate for use in TR-34 key block generation.
-
#signing_key_certificate ⇒ String
The signing key certificate in PEM format (base64 encoded) of the public key for signature within the TR-34 key block.
-
#signing_key_certificate_chain ⇒ String
The root certificate authority (CA) that signed the signing key certificate in PEM format (base64 encoded).
Instance Attribute Details
#export_token ⇒ String
The export token to initiate key export from Amazon Web Services Payment Cryptography. The export token expires after 30 days. You can use the same export token to export multiple keys from the same service account.
959 960 961 962 963 964 965 966 967 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 959 class GetParametersForExportOutput < Struct.new( :signing_key_certificate, :signing_key_certificate_chain, :signing_key_algorithm, :export_token, :parameters_valid_until_timestamp) SENSITIVE = [] include Aws::Structure end |
#parameters_valid_until_timestamp ⇒ Time
The validity period of the export token.
959 960 961 962 963 964 965 966 967 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 959 class GetParametersForExportOutput < Struct.new( :signing_key_certificate, :signing_key_certificate_chain, :signing_key_algorithm, :export_token, :parameters_valid_until_timestamp) SENSITIVE = [] include Aws::Structure end |
#signing_key_algorithm ⇒ String
The algorithm of the signing key certificate for use in TR-34 key block generation. RSA_2048 is the only signing key algorithm allowed.
959 960 961 962 963 964 965 966 967 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 959 class GetParametersForExportOutput < Struct.new( :signing_key_certificate, :signing_key_certificate_chain, :signing_key_algorithm, :export_token, :parameters_valid_until_timestamp) SENSITIVE = [] include Aws::Structure end |
#signing_key_certificate ⇒ String
The signing key certificate in PEM format (base64 encoded) of the public key for signature within the TR-34 key block. The certificate expires after 30 days.
959 960 961 962 963 964 965 966 967 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 959 class GetParametersForExportOutput < Struct.new( :signing_key_certificate, :signing_key_certificate_chain, :signing_key_algorithm, :export_token, :parameters_valid_until_timestamp) SENSITIVE = [] include Aws::Structure end |
#signing_key_certificate_chain ⇒ String
The root certificate authority (CA) that signed the signing key certificate in PEM format (base64 encoded).
959 960 961 962 963 964 965 966 967 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 959 class GetParametersForExportOutput < Struct.new( :signing_key_certificate, :signing_key_certificate_chain, :signing_key_algorithm, :export_token, :parameters_valid_until_timestamp) SENSITIVE = [] include Aws::Structure end |