Class: Aws::PaymentCryptography::Types::GetParametersForImportOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-paymentcryptography/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#import_tokenString

The import token to initiate key import into Amazon Web Services Payment Cryptography. The import token expires after 30 days. You can use the same import token to import multiple keys to the same service account.

Returns:

  • (String)


1027
1028
1029
1030
1031
1032
1033
1034
1035
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1027

class GetParametersForImportOutput < Struct.new(
  :wrapping_key_certificate,
  :wrapping_key_certificate_chain,
  :wrapping_key_algorithm,
  :import_token,
  :parameters_valid_until_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#parameters_valid_until_timestampTime

The validity period of the import token.

Returns:

  • (Time)


1027
1028
1029
1030
1031
1032
1033
1034
1035
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1027

class GetParametersForImportOutput < Struct.new(
  :wrapping_key_certificate,
  :wrapping_key_certificate_chain,
  :wrapping_key_algorithm,
  :import_token,
  :parameters_valid_until_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#wrapping_key_algorithmString

The algorithm of the wrapping key for use within TR-34 WrappedKeyBlock or RSA WrappedKeyCryptogram.

Returns:

  • (String)


1027
1028
1029
1030
1031
1032
1033
1034
1035
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1027

class GetParametersForImportOutput < Struct.new(
  :wrapping_key_certificate,
  :wrapping_key_certificate_chain,
  :wrapping_key_algorithm,
  :import_token,
  :parameters_valid_until_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#wrapping_key_certificateString

The wrapping key certificate in PEM format (base64 encoded) of the wrapping key for use within the TR-34 key block. The certificate expires in 30 days.

Returns:

  • (String)


1027
1028
1029
1030
1031
1032
1033
1034
1035
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1027

class GetParametersForImportOutput < Struct.new(
  :wrapping_key_certificate,
  :wrapping_key_certificate_chain,
  :wrapping_key_algorithm,
  :import_token,
  :parameters_valid_until_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#wrapping_key_certificate_chainString

The Amazon Web Services Payment Cryptography root certificate authority (CA) that signed the wrapping key certificate in PEM format (base64 encoded).

Returns:

  • (String)


1027
1028
1029
1030
1031
1032
1033
1034
1035
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1027

class GetParametersForImportOutput < Struct.new(
  :wrapping_key_certificate,
  :wrapping_key_certificate_chain,
  :wrapping_key_algorithm,
  :import_token,
  :parameters_valid_until_timestamp)
  SENSITIVE = []
  include Aws::Structure
end