Class: Aws::PaymentCryptography::Types::GetParametersForImportOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::GetParametersForImportOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#import_token ⇒ String
The import token to initiate key import into Amazon Web Services Payment Cryptography.
-
#parameters_valid_until_timestamp ⇒ Time
The validity period of the import token.
-
#wrapping_key_algorithm ⇒ String
The algorithm of the wrapping key for use within TR-34 WrappedKeyBlock or RSA WrappedKeyCryptogram.
-
#wrapping_key_certificate ⇒ String
The wrapping key certificate in PEM format (base64 encoded) of the wrapping key for use within the TR-34 key block.
-
#wrapping_key_certificate_chain ⇒ String
The Amazon Web Services Payment Cryptography root certificate authority (CA) that signed the wrapping key certificate in PEM format (base64 encoded).
Instance Attribute Details
#import_token ⇒ String
The import token to initiate key import into Amazon Web Services Payment Cryptography. The import token expires after 30 days. You can use the same import token to import multiple keys to the same service account.
1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1027 class GetParametersForImportOutput < Struct.new( :wrapping_key_certificate, :wrapping_key_certificate_chain, :wrapping_key_algorithm, :import_token, :parameters_valid_until_timestamp) SENSITIVE = [] include Aws::Structure end |
#parameters_valid_until_timestamp ⇒ Time
The validity period of the import token.
1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1027 class GetParametersForImportOutput < Struct.new( :wrapping_key_certificate, :wrapping_key_certificate_chain, :wrapping_key_algorithm, :import_token, :parameters_valid_until_timestamp) SENSITIVE = [] include Aws::Structure end |
#wrapping_key_algorithm ⇒ String
The algorithm of the wrapping key for use within TR-34 WrappedKeyBlock or RSA WrappedKeyCryptogram.
1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1027 class GetParametersForImportOutput < Struct.new( :wrapping_key_certificate, :wrapping_key_certificate_chain, :wrapping_key_algorithm, :import_token, :parameters_valid_until_timestamp) SENSITIVE = [] include Aws::Structure end |
#wrapping_key_certificate ⇒ String
The wrapping key certificate in PEM format (base64 encoded) of the wrapping key for use within the TR-34 key block. The certificate expires in 30 days.
1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1027 class GetParametersForImportOutput < Struct.new( :wrapping_key_certificate, :wrapping_key_certificate_chain, :wrapping_key_algorithm, :import_token, :parameters_valid_until_timestamp) SENSITIVE = [] include Aws::Structure end |
#wrapping_key_certificate_chain ⇒ String
The Amazon Web Services Payment Cryptography root certificate authority (CA) that signed the wrapping key certificate in PEM format (base64 encoded).
1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1027 class GetParametersForImportOutput < Struct.new( :wrapping_key_certificate, :wrapping_key_certificate_chain, :wrapping_key_algorithm, :import_token, :parameters_valid_until_timestamp) SENSITIVE = [] include Aws::Structure end |