Class: Aws::PaymentCryptography::Types::ImportDiffieHellmanTr31KeyBlock
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::ImportDiffieHellmanTr31KeyBlock
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Key derivation parameter information for key material import using asymmetric ECDH key exchange method.
Constant Summary collapse
- SENSITIVE =
[:wrapped_key_block]
Instance Attribute Summary collapse
-
#certificate_authority_public_key_identifier ⇒ String
The ‘keyARN` of the CA that signed the `PublicKeyCertificate` for the client’s receiving ECC key pair.
-
#derivation_data ⇒ Types::DiffieHellmanDerivationData
The shared information used when deriving a key using ECDH.
-
#derive_key_algorithm ⇒ String
The key algorithm of the shared derived ECDH key.
-
#key_derivation_function ⇒ String
The key derivation function to use when deriving a key using ECDH.
-
#key_derivation_hash_algorithm ⇒ String
The hash type to use when deriving a key using ECDH.
-
#private_key_identifier ⇒ String
The ‘keyARN` of the asymmetric ECC key created within Amazon Web Services Payment Cryptography.
-
#public_key_certificate ⇒ String
The public key certificate of the client’s receiving ECC key pair, in PEM format (base64 encoded), to use for ECDH key derivation.
-
#wrapped_key_block ⇒ String
The ECDH wrapped key block to import.
Instance Attribute Details
#certificate_authority_public_key_identifier ⇒ String
The ‘keyARN` of the CA that signed the `PublicKeyCertificate` for the client’s receiving ECC key pair.
1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1339 class ImportDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :wrapped_key_block) SENSITIVE = [:wrapped_key_block] include Aws::Structure end |
#derivation_data ⇒ Types::DiffieHellmanDerivationData
The shared information used when deriving a key using ECDH.
1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1339 class ImportDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :wrapped_key_block) SENSITIVE = [:wrapped_key_block] include Aws::Structure end |
#derive_key_algorithm ⇒ String
The key algorithm of the shared derived ECDH key.
1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1339 class ImportDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :wrapped_key_block) SENSITIVE = [:wrapped_key_block] include Aws::Structure end |
#key_derivation_function ⇒ String
The key derivation function to use when deriving a key using ECDH.
1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1339 class ImportDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :wrapped_key_block) SENSITIVE = [:wrapped_key_block] include Aws::Structure end |
#key_derivation_hash_algorithm ⇒ String
The hash type to use when deriving a key using ECDH.
1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1339 class ImportDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :wrapped_key_block) SENSITIVE = [:wrapped_key_block] include Aws::Structure end |
#private_key_identifier ⇒ String
The ‘keyARN` of the asymmetric ECC key created within Amazon Web Services Payment Cryptography.
1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1339 class ImportDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :wrapped_key_block) SENSITIVE = [:wrapped_key_block] include Aws::Structure end |
#public_key_certificate ⇒ String
The public key certificate of the client’s receiving ECC key pair, in PEM format (base64 encoded), to use for ECDH key derivation.
1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1339 class ImportDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :wrapped_key_block) SENSITIVE = [:wrapped_key_block] include Aws::Structure end |
#wrapped_key_block ⇒ String
The ECDH wrapped key block to import.
1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1339 class ImportDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :wrapped_key_block) SENSITIVE = [:wrapped_key_block] include Aws::Structure end |