Class: Aws::PaymentCryptography::Types::ImportKeyCryptogram
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::ImportKeyCryptogram
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Parameter information for key material import using asymmetric RSA wrap and unwrap key exchange method.
Constant Summary collapse
- SENSITIVE =
[:wrapped_key_cryptogram]
Instance Attribute Summary collapse
-
#exportable ⇒ Boolean
Specifies whether the key is exportable from the service.
-
#import_token ⇒ String
The import token that initiates key import using the asymmetric RSA wrap and unwrap key exchange method into AWS Payment Cryptography.
-
#key_attributes ⇒ Types::KeyAttributes
The role of the key, the algorithm it supports, and the cryptographic operations allowed with the key.
-
#wrapped_key_cryptogram ⇒ String
The RSA wrapped key cryptogram under import.
-
#wrapping_spec ⇒ String
The wrapping spec for the wrapped key cryptogram.
Instance Attribute Details
#exportable ⇒ Boolean
Specifies whether the key is exportable from the service.
1382 1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1382 class ImportKeyCryptogram < Struct.new( :key_attributes, :exportable, :wrapped_key_cryptogram, :import_token, :wrapping_spec) SENSITIVE = [:wrapped_key_cryptogram] include Aws::Structure end |
#import_token ⇒ String
The import token that initiates key import using the asymmetric RSA wrap and unwrap key exchange method into AWS Payment Cryptography. It expires after 30 days. You can use the same import token to import multiple keys to the same service account.
1382 1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1382 class ImportKeyCryptogram < Struct.new( :key_attributes, :exportable, :wrapped_key_cryptogram, :import_token, :wrapping_spec) SENSITIVE = [:wrapped_key_cryptogram] include Aws::Structure end |
#key_attributes ⇒ Types::KeyAttributes
The role of the key, the algorithm it supports, and the cryptographic operations allowed with the key. This data is immutable after the key is created.
1382 1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1382 class ImportKeyCryptogram < Struct.new( :key_attributes, :exportable, :wrapped_key_cryptogram, :import_token, :wrapping_spec) SENSITIVE = [:wrapped_key_cryptogram] include Aws::Structure end |
#wrapped_key_cryptogram ⇒ String
The RSA wrapped key cryptogram under import.
1382 1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1382 class ImportKeyCryptogram < Struct.new( :key_attributes, :exportable, :wrapped_key_cryptogram, :import_token, :wrapping_spec) SENSITIVE = [:wrapped_key_cryptogram] include Aws::Structure end |
#wrapping_spec ⇒ String
The wrapping spec for the wrapped key cryptogram.
1382 1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1382 class ImportKeyCryptogram < Struct.new( :key_attributes, :exportable, :wrapped_key_cryptogram, :import_token, :wrapping_spec) SENSITIVE = [:wrapped_key_cryptogram] include Aws::Structure end |