Class: Aws::PaymentCryptography::Types::ImportKeyMaterial
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::ImportKeyMaterial
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
ImportKeyMaterial is a union - when making an API calls you must set exactly one of the members.
Parameter information for key material import into Amazon Web Services Payment Cryptography using TR-31 or TR-34 or RSA wrap and unwrap key exchange method.
Direct Known Subclasses
As2805KeyCryptogram, DiffieHellmanTr31KeyBlock, KeyCryptogram, RootCertificatePublicKey, Tr31KeyBlock, Tr34KeyBlock, TrustedCertificatePublicKey, Unknown
Defined Under Namespace
Classes: As2805KeyCryptogram, DiffieHellmanTr31KeyBlock, KeyCryptogram, RootCertificatePublicKey, Tr31KeyBlock, Tr34KeyBlock, TrustedCertificatePublicKey, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#as_2805_key_cryptogram ⇒ Types::ImportAs2805KeyCryptogram
Parameter information for key material import using AS2805 key cryptogram format.
-
#diffie_hellman_tr_31_key_block ⇒ Types::ImportDiffieHellmanTr31KeyBlock
Key derivation parameter information for key material import using asymmetric ECDH key exchange method.
-
#key_cryptogram ⇒ Types::ImportKeyCryptogram
Parameter information for key material import using asymmetric RSA wrap and unwrap key exchange method.
-
#root_certificate_public_key ⇒ Types::RootCertificatePublicKey
Parameter information for root public key certificate import.
-
#tr_31_key_block ⇒ Types::ImportTr31KeyBlock
Parameter information for key material import using symmetric TR-31 key exchange method.
-
#tr_34_key_block ⇒ Types::ImportTr34KeyBlock
Parameter information for key material import using the asymmetric TR-34 key exchange method.
-
#trusted_certificate_public_key ⇒ Types::TrustedCertificatePublicKey
Parameter information for trusted public key certificate import.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#as_2805_key_cryptogram ⇒ Types::ImportAs2805KeyCryptogram
Parameter information for key material import using AS2805 key cryptogram format.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1520 class ImportKeyMaterial < Struct.new( :root_certificate_public_key, :trusted_certificate_public_key, :tr_31_key_block, :tr_34_key_block, :key_cryptogram, :diffie_hellman_tr_31_key_block, :as_2805_key_cryptogram, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RootCertificatePublicKey < ImportKeyMaterial; end class TrustedCertificatePublicKey < ImportKeyMaterial; end class Tr31KeyBlock < ImportKeyMaterial; end class Tr34KeyBlock < ImportKeyMaterial; end class KeyCryptogram < ImportKeyMaterial; end class DiffieHellmanTr31KeyBlock < ImportKeyMaterial; end class As2805KeyCryptogram < ImportKeyMaterial; end class Unknown < ImportKeyMaterial; end end |
#diffie_hellman_tr_31_key_block ⇒ Types::ImportDiffieHellmanTr31KeyBlock
Key derivation parameter information for key material import using asymmetric ECDH key exchange method.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1520 class ImportKeyMaterial < Struct.new( :root_certificate_public_key, :trusted_certificate_public_key, :tr_31_key_block, :tr_34_key_block, :key_cryptogram, :diffie_hellman_tr_31_key_block, :as_2805_key_cryptogram, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RootCertificatePublicKey < ImportKeyMaterial; end class TrustedCertificatePublicKey < ImportKeyMaterial; end class Tr31KeyBlock < ImportKeyMaterial; end class Tr34KeyBlock < ImportKeyMaterial; end class KeyCryptogram < ImportKeyMaterial; end class DiffieHellmanTr31KeyBlock < ImportKeyMaterial; end class As2805KeyCryptogram < ImportKeyMaterial; end class Unknown < ImportKeyMaterial; end end |
#key_cryptogram ⇒ Types::ImportKeyCryptogram
Parameter information for key material import using asymmetric RSA wrap and unwrap key exchange method.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1520 class ImportKeyMaterial < Struct.new( :root_certificate_public_key, :trusted_certificate_public_key, :tr_31_key_block, :tr_34_key_block, :key_cryptogram, :diffie_hellman_tr_31_key_block, :as_2805_key_cryptogram, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RootCertificatePublicKey < ImportKeyMaterial; end class TrustedCertificatePublicKey < ImportKeyMaterial; end class Tr31KeyBlock < ImportKeyMaterial; end class Tr34KeyBlock < ImportKeyMaterial; end class KeyCryptogram < ImportKeyMaterial; end class DiffieHellmanTr31KeyBlock < ImportKeyMaterial; end class As2805KeyCryptogram < ImportKeyMaterial; end class Unknown < ImportKeyMaterial; end end |
#root_certificate_public_key ⇒ Types::RootCertificatePublicKey
Parameter information for root public key certificate import.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1520 class ImportKeyMaterial < Struct.new( :root_certificate_public_key, :trusted_certificate_public_key, :tr_31_key_block, :tr_34_key_block, :key_cryptogram, :diffie_hellman_tr_31_key_block, :as_2805_key_cryptogram, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RootCertificatePublicKey < ImportKeyMaterial; end class TrustedCertificatePublicKey < ImportKeyMaterial; end class Tr31KeyBlock < ImportKeyMaterial; end class Tr34KeyBlock < ImportKeyMaterial; end class KeyCryptogram < ImportKeyMaterial; end class DiffieHellmanTr31KeyBlock < ImportKeyMaterial; end class As2805KeyCryptogram < ImportKeyMaterial; end class Unknown < ImportKeyMaterial; end end |
#tr_31_key_block ⇒ Types::ImportTr31KeyBlock
Parameter information for key material import using symmetric TR-31 key exchange method.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1520 class ImportKeyMaterial < Struct.new( :root_certificate_public_key, :trusted_certificate_public_key, :tr_31_key_block, :tr_34_key_block, :key_cryptogram, :diffie_hellman_tr_31_key_block, :as_2805_key_cryptogram, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RootCertificatePublicKey < ImportKeyMaterial; end class TrustedCertificatePublicKey < ImportKeyMaterial; end class Tr31KeyBlock < ImportKeyMaterial; end class Tr34KeyBlock < ImportKeyMaterial; end class KeyCryptogram < ImportKeyMaterial; end class DiffieHellmanTr31KeyBlock < ImportKeyMaterial; end class As2805KeyCryptogram < ImportKeyMaterial; end class Unknown < ImportKeyMaterial; end end |
#tr_34_key_block ⇒ Types::ImportTr34KeyBlock
Parameter information for key material import using the asymmetric TR-34 key exchange method.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1520 class ImportKeyMaterial < Struct.new( :root_certificate_public_key, :trusted_certificate_public_key, :tr_31_key_block, :tr_34_key_block, :key_cryptogram, :diffie_hellman_tr_31_key_block, :as_2805_key_cryptogram, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RootCertificatePublicKey < ImportKeyMaterial; end class TrustedCertificatePublicKey < ImportKeyMaterial; end class Tr31KeyBlock < ImportKeyMaterial; end class Tr34KeyBlock < ImportKeyMaterial; end class KeyCryptogram < ImportKeyMaterial; end class DiffieHellmanTr31KeyBlock < ImportKeyMaterial; end class As2805KeyCryptogram < ImportKeyMaterial; end class Unknown < ImportKeyMaterial; end end |
#trusted_certificate_public_key ⇒ Types::TrustedCertificatePublicKey
Parameter information for trusted public key certificate import.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1520 class ImportKeyMaterial < Struct.new( :root_certificate_public_key, :trusted_certificate_public_key, :tr_31_key_block, :tr_34_key_block, :key_cryptogram, :diffie_hellman_tr_31_key_block, :as_2805_key_cryptogram, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RootCertificatePublicKey < ImportKeyMaterial; end class TrustedCertificatePublicKey < ImportKeyMaterial; end class Tr31KeyBlock < ImportKeyMaterial; end class Tr34KeyBlock < ImportKeyMaterial; end class KeyCryptogram < ImportKeyMaterial; end class DiffieHellmanTr31KeyBlock < ImportKeyMaterial; end class As2805KeyCryptogram < ImportKeyMaterial; end class Unknown < ImportKeyMaterial; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1520 1521 1522 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1520 def unknown @unknown end |