Class: Aws::PaymentCryptography::Types::ImportKeyMaterial

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-paymentcryptography/types.rb

Overview

Note:

ImportKeyMaterial is a union - when making an API calls you must set exactly one of the members.

Parameter information for key material import into Amazon Web Services Payment Cryptography using TR-31 or TR-34 or RSA wrap and unwrap key exchange method.

Defined Under Namespace

Classes: As2805KeyCryptogram, DiffieHellmanTr31KeyBlock, KeyCryptogram, RootCertificatePublicKey, Tr31KeyBlock, Tr34KeyBlock, TrustedCertificatePublicKey, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#as_2805_key_cryptogramTypes::ImportAs2805KeyCryptogram

Parameter information for key material import using AS2805 key cryptogram format.



1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1514

class ImportKeyMaterial < Struct.new(
  :root_certificate_public_key,
  :trusted_certificate_public_key,
  :tr_31_key_block,
  :tr_34_key_block,
  :key_cryptogram,
  :diffie_hellman_tr_31_key_block,
  :as_2805_key_cryptogram,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class RootCertificatePublicKey < ImportKeyMaterial; end
  class TrustedCertificatePublicKey < ImportKeyMaterial; end
  class Tr31KeyBlock < ImportKeyMaterial; end
  class Tr34KeyBlock < ImportKeyMaterial; end
  class KeyCryptogram < ImportKeyMaterial; end
  class DiffieHellmanTr31KeyBlock < ImportKeyMaterial; end
  class As2805KeyCryptogram < ImportKeyMaterial; end
  class Unknown < ImportKeyMaterial; end
end

#diffie_hellman_tr_31_key_blockTypes::ImportDiffieHellmanTr31KeyBlock

Key derivation parameter information for key material import using asymmetric ECDH key exchange method.



1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1514

class ImportKeyMaterial < Struct.new(
  :root_certificate_public_key,
  :trusted_certificate_public_key,
  :tr_31_key_block,
  :tr_34_key_block,
  :key_cryptogram,
  :diffie_hellman_tr_31_key_block,
  :as_2805_key_cryptogram,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class RootCertificatePublicKey < ImportKeyMaterial; end
  class TrustedCertificatePublicKey < ImportKeyMaterial; end
  class Tr31KeyBlock < ImportKeyMaterial; end
  class Tr34KeyBlock < ImportKeyMaterial; end
  class KeyCryptogram < ImportKeyMaterial; end
  class DiffieHellmanTr31KeyBlock < ImportKeyMaterial; end
  class As2805KeyCryptogram < ImportKeyMaterial; end
  class Unknown < ImportKeyMaterial; end
end

#key_cryptogramTypes::ImportKeyCryptogram

Parameter information for key material import using asymmetric RSA wrap and unwrap key exchange method.



1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1514

class ImportKeyMaterial < Struct.new(
  :root_certificate_public_key,
  :trusted_certificate_public_key,
  :tr_31_key_block,
  :tr_34_key_block,
  :key_cryptogram,
  :diffie_hellman_tr_31_key_block,
  :as_2805_key_cryptogram,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class RootCertificatePublicKey < ImportKeyMaterial; end
  class TrustedCertificatePublicKey < ImportKeyMaterial; end
  class Tr31KeyBlock < ImportKeyMaterial; end
  class Tr34KeyBlock < ImportKeyMaterial; end
  class KeyCryptogram < ImportKeyMaterial; end
  class DiffieHellmanTr31KeyBlock < ImportKeyMaterial; end
  class As2805KeyCryptogram < ImportKeyMaterial; end
  class Unknown < ImportKeyMaterial; end
end

#root_certificate_public_keyTypes::RootCertificatePublicKey

Parameter information for root public key certificate import.



1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1514

class ImportKeyMaterial < Struct.new(
  :root_certificate_public_key,
  :trusted_certificate_public_key,
  :tr_31_key_block,
  :tr_34_key_block,
  :key_cryptogram,
  :diffie_hellman_tr_31_key_block,
  :as_2805_key_cryptogram,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class RootCertificatePublicKey < ImportKeyMaterial; end
  class TrustedCertificatePublicKey < ImportKeyMaterial; end
  class Tr31KeyBlock < ImportKeyMaterial; end
  class Tr34KeyBlock < ImportKeyMaterial; end
  class KeyCryptogram < ImportKeyMaterial; end
  class DiffieHellmanTr31KeyBlock < ImportKeyMaterial; end
  class As2805KeyCryptogram < ImportKeyMaterial; end
  class Unknown < ImportKeyMaterial; end
end

#tr_31_key_blockTypes::ImportTr31KeyBlock

Parameter information for key material import using symmetric TR-31 key exchange method.



1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1514

class ImportKeyMaterial < Struct.new(
  :root_certificate_public_key,
  :trusted_certificate_public_key,
  :tr_31_key_block,
  :tr_34_key_block,
  :key_cryptogram,
  :diffie_hellman_tr_31_key_block,
  :as_2805_key_cryptogram,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class RootCertificatePublicKey < ImportKeyMaterial; end
  class TrustedCertificatePublicKey < ImportKeyMaterial; end
  class Tr31KeyBlock < ImportKeyMaterial; end
  class Tr34KeyBlock < ImportKeyMaterial; end
  class KeyCryptogram < ImportKeyMaterial; end
  class DiffieHellmanTr31KeyBlock < ImportKeyMaterial; end
  class As2805KeyCryptogram < ImportKeyMaterial; end
  class Unknown < ImportKeyMaterial; end
end

#tr_34_key_blockTypes::ImportTr34KeyBlock

Parameter information for key material import using the asymmetric TR-34 key exchange method.



1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1514

class ImportKeyMaterial < Struct.new(
  :root_certificate_public_key,
  :trusted_certificate_public_key,
  :tr_31_key_block,
  :tr_34_key_block,
  :key_cryptogram,
  :diffie_hellman_tr_31_key_block,
  :as_2805_key_cryptogram,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class RootCertificatePublicKey < ImportKeyMaterial; end
  class TrustedCertificatePublicKey < ImportKeyMaterial; end
  class Tr31KeyBlock < ImportKeyMaterial; end
  class Tr34KeyBlock < ImportKeyMaterial; end
  class KeyCryptogram < ImportKeyMaterial; end
  class DiffieHellmanTr31KeyBlock < ImportKeyMaterial; end
  class As2805KeyCryptogram < ImportKeyMaterial; end
  class Unknown < ImportKeyMaterial; end
end

#trusted_certificate_public_keyTypes::TrustedCertificatePublicKey

Parameter information for trusted public key certificate import.



1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1514

class ImportKeyMaterial < Struct.new(
  :root_certificate_public_key,
  :trusted_certificate_public_key,
  :tr_31_key_block,
  :tr_34_key_block,
  :key_cryptogram,
  :diffie_hellman_tr_31_key_block,
  :as_2805_key_cryptogram,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class RootCertificatePublicKey < ImportKeyMaterial; end
  class TrustedCertificatePublicKey < ImportKeyMaterial; end
  class Tr31KeyBlock < ImportKeyMaterial; end
  class Tr34KeyBlock < ImportKeyMaterial; end
  class KeyCryptogram < ImportKeyMaterial; end
  class DiffieHellmanTr31KeyBlock < ImportKeyMaterial; end
  class As2805KeyCryptogram < ImportKeyMaterial; end
  class Unknown < ImportKeyMaterial; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1514
1515
1516
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1514

def unknown
  @unknown
end