Class: Aws::PaymentCryptography::Types::ImportTr34KeyBlock

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-paymentcryptography/types.rb

Overview

Parameter information for key material import using the asymmetric TR-34 key exchange method.

Constant Summary collapse

SENSITIVE =
[:wrapped_key_block]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_authority_public_key_identifierString

The ‘KeyARN` of the certificate chain that signs the signing key certificate during TR-34 key import.

Returns:

  • (String)


1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1616

class ImportTr34KeyBlock < Struct.new(
  :certificate_authority_public_key_identifier,
  :signing_key_certificate,
  :import_token,
  :wrapping_key_identifier,
  :wrapping_key_certificate,
  :wrapped_key_block,
  :key_block_format,
  :random_nonce)
  SENSITIVE = [:wrapped_key_block]
  include Aws::Structure
end

#import_tokenString

The import token that initiates key import using the asymmetric TR-34 key exchange method into Amazon Web Services Payment Cryptography. It expires after 30 days. You can use the same import token to import multiple keys to the same service account.

Returns:

  • (String)


1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1616

class ImportTr34KeyBlock < Struct.new(
  :certificate_authority_public_key_identifier,
  :signing_key_certificate,
  :import_token,
  :wrapping_key_identifier,
  :wrapping_key_certificate,
  :wrapped_key_block,
  :key_block_format,
  :random_nonce)
  SENSITIVE = [:wrapped_key_block]
  include Aws::Structure
end

#key_block_formatString

The key block format to use during key import. The only value allowed is ‘X9_TR34_2012`.

Returns:

  • (String)


1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1616

class ImportTr34KeyBlock < Struct.new(
  :certificate_authority_public_key_identifier,
  :signing_key_certificate,
  :import_token,
  :wrapping_key_identifier,
  :wrapping_key_certificate,
  :wrapped_key_block,
  :key_block_format,
  :random_nonce)
  SENSITIVE = [:wrapped_key_block]
  include Aws::Structure
end

#random_nonceString

A random number value that is unique to the TR-34 key block generated using 2 pass. The operation will fail, if a random nonce value is not provided for a TR-34 key block generated using 2 pass.

Returns:

  • (String)


1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1616

class ImportTr34KeyBlock < Struct.new(
  :certificate_authority_public_key_identifier,
  :signing_key_certificate,
  :import_token,
  :wrapping_key_identifier,
  :wrapping_key_certificate,
  :wrapped_key_block,
  :key_block_format,
  :random_nonce)
  SENSITIVE = [:wrapped_key_block]
  include Aws::Structure
end

#signing_key_certificateString

The public key component in PEM certificate format of the private key that signs the KDH TR-34 WrappedKeyBlock.

Returns:

  • (String)


1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1616

class ImportTr34KeyBlock < Struct.new(
  :certificate_authority_public_key_identifier,
  :signing_key_certificate,
  :import_token,
  :wrapping_key_identifier,
  :wrapping_key_certificate,
  :wrapped_key_block,
  :key_block_format,
  :random_nonce)
  SENSITIVE = [:wrapped_key_block]
  include Aws::Structure
end

#wrapped_key_blockString

The TR-34 wrapped key block to import.

Returns:

  • (String)


1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1616

class ImportTr34KeyBlock < Struct.new(
  :certificate_authority_public_key_identifier,
  :signing_key_certificate,
  :import_token,
  :wrapping_key_identifier,
  :wrapping_key_certificate,
  :wrapped_key_block,
  :key_block_format,
  :random_nonce)
  SENSITIVE = [:wrapped_key_block]
  include Aws::Structure
end

#wrapping_key_certificateString

The certificate used to wrap the TR-34 key block.

Returns:

  • (String)


1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1616

class ImportTr34KeyBlock < Struct.new(
  :certificate_authority_public_key_identifier,
  :signing_key_certificate,
  :import_token,
  :wrapping_key_identifier,
  :wrapping_key_certificate,
  :wrapped_key_block,
  :key_block_format,
  :random_nonce)
  SENSITIVE = [:wrapped_key_block]
  include Aws::Structure
end

#wrapping_key_identifierString

Key Identifier used for unwrapping the import key

Returns:

  • (String)


1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1616

class ImportTr34KeyBlock < Struct.new(
  :certificate_authority_public_key_identifier,
  :signing_key_certificate,
  :import_token,
  :wrapping_key_identifier,
  :wrapping_key_certificate,
  :wrapped_key_block,
  :key_block_format,
  :random_nonce)
  SENSITIVE = [:wrapped_key_block]
  include Aws::Structure
end