Class: Aws::PaymentCryptography::Types::KeyAttributes
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::KeyAttributes
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
The role of the key, the algorithm it supports, and the cryptographic operations allowed with the key. This data is immutable after the key is created.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key_algorithm ⇒ String
The key algorithm to be use during creation of an Amazon Web Services Payment Cryptography key.
-
#key_class ⇒ String
The type of Amazon Web Services Payment Cryptography key to create, which determines the classification of the cryptographic method and whether Amazon Web Services Payment Cryptography key contains a symmetric key or an asymmetric key pair.
-
#key_modes_of_use ⇒ Types::KeyModesOfUse
The list of cryptographic operations that you can perform using the key.
-
#key_usage ⇒ String
The cryptographic usage of an Amazon Web Services Payment Cryptography key as defined in section A.5.2 of the TR-31 spec.
Instance Attribute Details
#key_algorithm ⇒ String
The key algorithm to be use during creation of an Amazon Web Services Payment Cryptography key.
For symmetric keys, Amazon Web Services Payment Cryptography supports ‘AES` and `TDES` algorithms. For asymmetric keys, Amazon Web Services Payment Cryptography supports `RSA` and `ECC_NIST` algorithms.
1845 1846 1847 1848 1849 1850 1851 1852 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1845 class KeyAttributes < Struct.new( :key_usage, :key_class, :key_algorithm, :key_modes_of_use) SENSITIVE = [] include Aws::Structure end |
#key_class ⇒ String
The type of Amazon Web Services Payment Cryptography key to create, which determines the classification of the cryptographic method and whether Amazon Web Services Payment Cryptography key contains a symmetric key or an asymmetric key pair.
1845 1846 1847 1848 1849 1850 1851 1852 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1845 class KeyAttributes < Struct.new( :key_usage, :key_class, :key_algorithm, :key_modes_of_use) SENSITIVE = [] include Aws::Structure end |
#key_modes_of_use ⇒ Types::KeyModesOfUse
The list of cryptographic operations that you can perform using the key.
1845 1846 1847 1848 1849 1850 1851 1852 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1845 class KeyAttributes < Struct.new( :key_usage, :key_class, :key_algorithm, :key_modes_of_use) SENSITIVE = [] include Aws::Structure end |
#key_usage ⇒ String
The cryptographic usage of an Amazon Web Services Payment Cryptography key as defined in section A.5.2 of the TR-31 spec.
1845 1846 1847 1848 1849 1850 1851 1852 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1845 class KeyAttributes < Struct.new( :key_usage, :key_class, :key_algorithm, :key_modes_of_use) SENSITIVE = [] include Aws::Structure end |