Class: Aws::PaymentCryptography::Types::KeyModesOfUse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::KeyModesOfUse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
The list of cryptographic operations that you can perform using the key. The modes of use are defined in section A.5.3 of the TR-31 spec.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#decrypt ⇒ Boolean
Specifies whether an Amazon Web Services Payment Cryptography key can be used to decrypt data.
-
#derive_key ⇒ Boolean
Specifies whether an Amazon Web Services Payment Cryptography key can be used to derive new keys.
-
#encrypt ⇒ Boolean
Specifies whether an Amazon Web Services Payment Cryptography key can be used to encrypt data.
-
#generate ⇒ Boolean
Specifies whether an Amazon Web Services Payment Cryptography key can be used to generate and verify other card and PIN verification keys.
-
#no_restrictions ⇒ Boolean
Specifies whether an Amazon Web Services Payment Cryptography key has no special restrictions other than the restrictions implied by ‘KeyUsage`.
-
#sign ⇒ Boolean
Specifies whether an Amazon Web Services Payment Cryptography key can be used for signing.
-
#unwrap ⇒ Boolean
Specifies whether an Amazon Web Services Payment Cryptography key can be used to unwrap other keys.
-
#verify ⇒ Boolean
Specifies whether an Amazon Web Services Payment Cryptography key can be used to verify signatures.
-
#wrap ⇒ Boolean
Specifies whether an Amazon Web Services Payment Cryptography key can be used to wrap other keys.
Instance Attribute Details
#decrypt ⇒ Boolean
Specifies whether an Amazon Web Services Payment Cryptography key can be used to decrypt data.
1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1965 class KeyModesOfUse < Struct.new( :encrypt, :decrypt, :wrap, :unwrap, :generate, :sign, :verify, :derive_key, :no_restrictions) SENSITIVE = [] include Aws::Structure end |
#derive_key ⇒ Boolean
Specifies whether an Amazon Web Services Payment Cryptography key can be used to derive new keys.
1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1965 class KeyModesOfUse < Struct.new( :encrypt, :decrypt, :wrap, :unwrap, :generate, :sign, :verify, :derive_key, :no_restrictions) SENSITIVE = [] include Aws::Structure end |
#encrypt ⇒ Boolean
Specifies whether an Amazon Web Services Payment Cryptography key can be used to encrypt data.
1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1965 class KeyModesOfUse < Struct.new( :encrypt, :decrypt, :wrap, :unwrap, :generate, :sign, :verify, :derive_key, :no_restrictions) SENSITIVE = [] include Aws::Structure end |
#generate ⇒ Boolean
Specifies whether an Amazon Web Services Payment Cryptography key can be used to generate and verify other card and PIN verification keys.
1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1965 class KeyModesOfUse < Struct.new( :encrypt, :decrypt, :wrap, :unwrap, :generate, :sign, :verify, :derive_key, :no_restrictions) SENSITIVE = [] include Aws::Structure end |
#no_restrictions ⇒ Boolean
Specifies whether an Amazon Web Services Payment Cryptography key has no special restrictions other than the restrictions implied by ‘KeyUsage`.
1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1965 class KeyModesOfUse < Struct.new( :encrypt, :decrypt, :wrap, :unwrap, :generate, :sign, :verify, :derive_key, :no_restrictions) SENSITIVE = [] include Aws::Structure end |
#sign ⇒ Boolean
Specifies whether an Amazon Web Services Payment Cryptography key can be used for signing.
1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1965 class KeyModesOfUse < Struct.new( :encrypt, :decrypt, :wrap, :unwrap, :generate, :sign, :verify, :derive_key, :no_restrictions) SENSITIVE = [] include Aws::Structure end |
#unwrap ⇒ Boolean
Specifies whether an Amazon Web Services Payment Cryptography key can be used to unwrap other keys.
1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1965 class KeyModesOfUse < Struct.new( :encrypt, :decrypt, :wrap, :unwrap, :generate, :sign, :verify, :derive_key, :no_restrictions) SENSITIVE = [] include Aws::Structure end |
#verify ⇒ Boolean
Specifies whether an Amazon Web Services Payment Cryptography key can be used to verify signatures.
1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1965 class KeyModesOfUse < Struct.new( :encrypt, :decrypt, :wrap, :unwrap, :generate, :sign, :verify, :derive_key, :no_restrictions) SENSITIVE = [] include Aws::Structure end |
#wrap ⇒ Boolean
Specifies whether an Amazon Web Services Payment Cryptography key can be used to wrap other keys.
1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1965 class KeyModesOfUse < Struct.new( :encrypt, :decrypt, :wrap, :unwrap, :generate, :sign, :verify, :derive_key, :no_restrictions) SENSITIVE = [] include Aws::Structure end |