Class: Aws::PaymentCryptography::Types::RestoreKeyInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::RestoreKeyInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key_identifier ⇒ String
The
KeyARNof the key to be restored within Amazon Web Services Payment Cryptography.
Instance Attribute Details
#key_identifier ⇒ String
The KeyARN of the key to be restored within Amazon Web Services Payment Cryptography.
1388 1389 1390 1391 1392 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 1388 class RestoreKeyInput < Struct.new( :key_identifier) SENSITIVE = [] include Aws::Structure end |