Class: Aws::PaymentCryptography::Types::RootCertificatePublicKey

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-paymentcryptography/types.rb

Overview

Parameter information for root public key certificate import.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#key_attributesTypes::KeyAttributes

The role of the key, the algorithm it supports, and the cryptographic operations allowed with the key. This data is immutable after the root public key is imported.



2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2458

class RootCertificatePublicKey < Struct.new(
  :key_attributes,
  :public_key_certificate)
  SENSITIVE = []
  include Aws::Structure
end

#public_key_certificateString

Parameter information for root public key certificate import.

Returns:

  • (String)


2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2458

class RootCertificatePublicKey < Struct.new(
  :key_attributes,
  :public_key_certificate)
  SENSITIVE = []
  include Aws::Structure
end