Class: Aws::PaymentCryptography::Types::ServiceQuotaExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::ServiceQuotaExceededException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
This request would cause a service quota to be exceeded.
You have reached the maximum number of keys, aliases, or other resources allowed in your account. Review your current usage and consider deleting unused resources or requesting a quota increase.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
2476 2477 2478 2479 2480 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2476 class ServiceQuotaExceededException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |