Class: Aws::PaymentCryptography::Types::ThrottlingException
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptography::Types::ThrottlingException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptography/types.rb
Overview
The request was denied due to request throttling.
You have exceeded the rate limits for Amazon Web Services Payment Cryptography API calls. Implement exponential backoff and retry logic in your application to handle throttling gracefully.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
2627 2628 2629 2630 2631 |
# File 'lib/aws-sdk-paymentcryptography/types.rb', line 2627 class ThrottlingException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |